@@ -21,7 +21,9 @@
 #include "config/configcompilercontext.hpp"
 #include "config/configcompiler.hpp"
 #include "config/configitembuilder.hpp"
+#include "config/expression.hpp"
 #include "base/application.hpp"
+#include "base/configuration.hpp"
 #include "base/logger.hpp"
 #include "base/timer.hpp"
 #include "base/utility.hpp"
@@ -94,6 +96,70 @@ static std::vector<String> GlobalArgumentCompletion(const String& argument, cons
 		return std::vector<String>();
 }
 
+static void HandleLegacyDefines()
+{
+#ifdef _WIN32
+	String dataPrefix = Utility::GetIcingaDataPath();
+#endif /* _WIN32 */
+
+	Value localStateDir = Configuration::LocalStateDir;
+
+	if (!localStateDir.IsEmpty()) {
+		Log(LogWarning, "icinga-app")
+			<< "Please do not set the deprecated 'LocalStateDir' constant,"
+			<< " use the 'DataDir', 'LogDir', 'CacheDir' and 'SpoolDir' constants instead!"
+			<< " For compatibility reasons, these are now set based on the 'LocalStateDir' constant.";
+
+#ifdef _WIN32
+		Configuration::DataDir = localStateDir + "\\lib\\icinga2";
+		Configuration::LogDir = localStateDir + "\\log\\icinga2";
+		Configuration::CacheDir = localStateDir + "\\cache\\icinga2";
+		Configuration::SpoolDir = localStateDir + "\\spool\\icinga2";
+	} else {
+		Configuration::LocalStateDir = dataPrefix + "\\var";
+#else /* _WIN32 */
+		Configuration::DataDir = localStateDir + "/lib/icinga2";
+		Configuration::LogDir = localStateDir + "/log/icinga2";
+		Configuration::CacheDir = localStateDir + "/cache/icinga2";
+		Configuration::SpoolDir = localStateDir + "/spool/icinga2";
+	} else {
+		Configuration::LocalStateDir = ICINGA_LOCALSTATEDIR;
+#endif /* _WIN32 */
+	}
+
+	Value sysconfDir = Configuration::SysconfDir;
+	if (!sysconfDir.IsEmpty()) {
+		Log(LogWarning, "icinga-app")
+			<< "Please do not set the deprecated 'Sysconfdir' constant, use the 'ConfigDir' constant instead! For compatibility reasons, their value is set based on the 'SysconfDir' constant.";
+
+#ifdef _WIN32
+		Configuration::ConfigDir = sysconfDir + "\\icinga2";
+	} else {
+		Configuration::SysconfDir = dataPrefix + "\\etc";
+#else /* _WIN32 */
+		Configuration::ConfigDir = sysconfDir + "/icinga2";
+	} else {
+		Configuration::SysconfDir = ICINGA_SYSCONFDIR;
+#endif /* _WIN32 */
+	}
+
+	Value runDir = Configuration::RunDir;
+	if (!runDir.IsEmpty()) {
+		Log(LogWarning, "icinga-app")
+			<< "Please do not set the deprecated 'RunDir' constant, use the 'InitRunDir' constant instead! For compatiblity reasons, their value is set based on the 'RunDir' constant.";
+
+#ifdef _WIN32
+		Configuration::InitRunDir = runDir + "\\icinga2";
+	} else {
+		Configuration::RunDir = dataPrefix + "\\var\\run";
+#else /* _WIN32 */
+		Configuration::InitRunDir = runDir + "/icinga2";
+	} else {
+		Configuration::RunDir = ICINGA_RUNDIR;
+#endif /* _WIN32 */
+	}
+}
+
 static int Main()
 {
 	int argc = Application::GetArgC();
@@ -128,31 +194,49 @@ static int Main()
 #ifdef _WIN32
 	bool builtinPaths = true;
 
+	/* Programm install location, C:/Program Files/Icinga2 */
 	String binaryPrefix = Utility::GetIcingaInstallPath();
+	/* Returns the datapath for daemons, %PROGRAMDATA%/icinga2 */
 	String dataPrefix = Utility::GetIcingaDataPath();
 
 	if (!binaryPrefix.IsEmpty() && !dataPrefix.IsEmpty()) {
-		Application::DeclarePrefixDir(binaryPrefix);
-		Application::DeclareSysconfDir(dataPrefix + "\\etc");
-		Application::DeclareRunDir(dataPrefix + "\\var\\run");
-		Application::DeclareLocalStateDir(dataPrefix + "\\var");
-		Application::DeclarePkgDataDir(binaryPrefix + "\\share\\icinga2");
-		Application::DeclareIncludeConfDir(binaryPrefix + "\\share\\icinga2\\include");
+		Configuration::PrefixDir = binaryPrefix;
+		Configuration::ProgramData = dataPrefix;
+
+		Configuration::ConfigDir = dataPrefix + "\\etc\\icinga2";
+
+		Configuration::DataDir =  dataPrefix + "\\var\\lib\\icinga2";
+		Configuration::LogDir = dataPrefix + "\\var\\log\\icinga2";
+		Configuration::CacheDir = dataPrefix + "\\var\\cache\\icinga2";
+		Configuration::SpoolDir = dataPrefix + "\\var\\spool\\icinga2";
+
+		/* Internal constants. */
+		Configuration::PkgDataDir = binaryPrefix + "\\share\\icinga2";
+		Configuration::IncludeConfDir = binaryPrefix + "\\share\\icinga2\\include";
 	} else {
 		Log(LogWarning, "icinga-app", "Registry key could not be read. Falling back to built-in paths.");
 
 #endif /* _WIN32 */
-		Application::DeclarePrefixDir(ICINGA_PREFIX);
-		Application::DeclareSysconfDir(ICINGA_SYSCONFDIR);
-		Application::DeclareRunDir(ICINGA_RUNDIR);
-		Application::DeclareLocalStateDir(ICINGA_LOCALSTATEDIR);
-		Application::DeclarePkgDataDir(ICINGA_PKGDATADIR);
-		Application::DeclareIncludeConfDir(ICINGA_INCLUDECONFDIR);
+		Configuration::ConfigDir = ICINGA_CONFIGDIR;
+
+		Configuration::DataDir = ICINGA_DATADIR;
+		Configuration::LogDir = ICINGA_LOGDIR;
+		Configuration::CacheDir = ICINGA_CACHEDIR;
+		Configuration::SpoolDir = ICINGA_SPOOLDIR;
+
+		Configuration::PrefixDir = ICINGA_PREFIX;
+
+		/* Internal constants. */
+		Configuration::PkgDataDir = ICINGA_PKGDATADIR;
+		Configuration::IncludeConfDir = ICINGA_INCLUDECONFDIR;
+
+		Configuration::InitRunDir = ICINGA_INITRUNDIR;
+
 #ifdef _WIN32
 	}
 #endif /* _WIN32 */
 
-	Application::DeclareZonesDir(Application::GetSysconfDir() + "/icinga2/zones.d");
+	Configuration::ZonesDir = Configuration::ConfigDir + "/zones.d";
 
 	String icingaUser = Utility::GetFromEnvironment("ICINGA2_USER");
 	if (icingaUser.IsEmpty())
@@ -162,17 +246,17 @@ static int Main()
 	if (icingaGroup.IsEmpty())
 		icingaGroup = ICINGA_GROUP;
 
-	Application::DeclareRunAsUser(icingaUser);
-	Application::DeclareRunAsGroup(icingaGroup);
+	Configuration::RunAsUser = icingaUser;
+	Configuration::RunAsGroup = icingaGroup;
 
 	if (!autocomplete) {
 #ifdef RLIMIT_NOFILE
 		String rLimitFiles = Utility::GetFromEnvironment("ICINGA2_RLIMIT_FILES");
 		if (rLimitFiles.IsEmpty())
-			Application::DeclareRLimitFiles(Application::GetDefaultRLimitFiles());
+			Configuration::RLimitFiles = Application::GetDefaultRLimitFiles();
 		else {
 			try {
-				Application::DeclareRLimitFiles(Convert::ToLong(rLimitFiles));
+				Configuration::RLimitFiles = Convert::ToLong(rLimitFiles);
 			} catch (const std::invalid_argument& ex) {
 				std::cout
 					<< "Error setting \"ICINGA2_RLIMIT_FILES\": " << ex.what() << '\n';
@@ -184,10 +268,10 @@ static int Main()
 #ifdef RLIMIT_NPROC
 		String rLimitProcesses = Utility::GetFromEnvironment("ICINGA2_RLIMIT_PROCESSES");
 		if (rLimitProcesses.IsEmpty())
-			Application::DeclareRLimitProcesses(Application::GetDefaultRLimitProcesses());
+			Configuration::RLimitProcesses = Application::GetDefaultRLimitProcesses();
 		else {
 			try {
-				Application::DeclareRLimitProcesses(Convert::ToLong(rLimitProcesses));
+				Configuration::RLimitProcesses = Convert::ToLong(rLimitProcesses);
 			} catch (const std::invalid_argument& ex) {
 				std::cout
 					<< "Error setting \"ICINGA2_RLIMIT_PROCESSES\": " << ex.what() << '\n';
@@ -199,10 +283,10 @@ static int Main()
 #ifdef RLIMIT_STACK
 		String rLimitStack = Utility::GetFromEnvironment("ICINGA2_RLIMIT_STACK");
 		if (rLimitStack.IsEmpty())
-			Application::DeclareRLimitStack(Application::GetDefaultRLimitStack());
+			Configuration::RLimitStack = Application::GetDefaultRLimitStack();
 		else {
 			try {
-				Application::DeclareRLimitStack(Convert::ToLong(rLimitStack));
+				Configuration::RLimitStack = Convert::ToLong(rLimitStack);
 			} catch (const std::invalid_argument& ex) {
 				std::cout
 					<< "Error setting \"ICINGA2_RLIMIT_STACK\": " << ex.what() << '\n';
@@ -212,22 +296,19 @@ static int Main()
 #endif /* RLIMIT_STACK */
 	}
 
-	Application::DeclareConcurrency(std::thread::hardware_concurrency());
-	Application::DeclareMaxConcurrentChecks(Application::GetDefaultMaxConcurrentChecks());
+	ScriptGlobal::Set("MaxConcurrentChecks", Application::GetDefaultMaxConcurrentChecks());
 
 	ScriptGlobal::Set("Environment", "production");
 
-	ScriptGlobal::Set("AttachDebugger", false);
+	ScriptGlobal::Set("System.PlatformKernel", Utility::GetPlatformKernel(), true);
+	ScriptGlobal::Set("System.PlatformKernelVersion", Utility::GetPlatformKernelVersion(), true);
+	ScriptGlobal::Set("System.PlatformName", Utility::GetPlatformName(), true);
+	ScriptGlobal::Set("System.PlatformVersion", Utility::GetPlatformVersion(), true);
+	ScriptGlobal::Set("System.PlatformArchitecture", Utility::GetPlatformArchitecture(), true);
 
-	ScriptGlobal::Set("PlatformKernel", Utility::GetPlatformKernel());
-	ScriptGlobal::Set("PlatformKernelVersion", Utility::GetPlatformKernelVersion());
-	ScriptGlobal::Set("PlatformName", Utility::GetPlatformName());
-	ScriptGlobal::Set("PlatformVersion", Utility::GetPlatformVersion());
-	ScriptGlobal::Set("PlatformArchitecture", Utility::GetPlatformArchitecture());
-
-	ScriptGlobal::Set("BuildHostName", ICINGA_BUILD_HOST_NAME);
-	ScriptGlobal::Set("BuildCompilerName", ICINGA_BUILD_COMPILER_NAME);
-	ScriptGlobal::Set("BuildCompilerVersion", ICINGA_BUILD_COMPILER_VERSION);
+	ScriptGlobal::Set("System.BuildHostName", ICINGA_BUILD_HOST_NAME, true);
+	ScriptGlobal::Set("System.BuildCompilerName", ICINGA_BUILD_COMPILER_NAME, true);
+	ScriptGlobal::Set("System.BuildCompilerVersion", ICINGA_BUILD_COMPILER_VERSION, true);
 
 	if (!autocomplete)
 		Application::SetResourceLimits();
@@ -277,7 +358,10 @@ static int Main()
 	GetUserName(username, &usernameLen);
 
 	std::ifstream userFile;
-	userFile.open(Application::GetSysconfDir() + "/icinga2/user");
+
+	/* The implicit string assignment is needed for Windows builds. */
+	String configDir = Configuration::ConfigDir;
+	userFile.open(configDir + "/user");
 
 	if (userFile && command && !Application::IsProcessElevated()) {
 		std::string userLine;
@@ -357,20 +441,42 @@ static int Main()
 				key = define;
 				value = "1";
 			}
-			ScriptGlobal::Set(key, value);
+
+			std::vector<String> keyTokens = key.Split(".");
+
+			std::unique_ptr<Expression> expr;
+			std::unique_ptr<VariableExpression> varExpr{new VariableExpression(keyTokens[0], {}, DebugInfo())};
+			expr = std::move(varExpr);
+
+			for (size_t i = 1; i < keyTokens.size(); i++) {
+				std::unique_ptr<IndexerExpression> indexerExpr{new IndexerExpression(std::move(expr), MakeLiteral(keyTokens[i]))};
+				indexerExpr->SetOverrideFrozen();
+				expr = std::move(indexerExpr);
+			}
+
+			std::unique_ptr<SetExpression> setExpr{new SetExpression(std::move(expr), OpSetLiteral, MakeLiteral(value))};
+			setExpr->SetOverrideFrozen();
+
+			ScriptFrame frame(true);
+			setExpr->Evaluate(frame);
 		}
 	}
 
+	Configuration::SetReadOnly(true);
+
+	/* Ensure that all defined constants work in the way we expect them. */
+	HandleLegacyDefines();
+
 	if (vm.count("script-debugger"))
 		Application::SetScriptDebuggerEnabled(true);
 
-	Application::DeclareStatePath(Application::GetLocalStateDir() + "/lib/icinga2/icinga2.state");
-	Application::DeclareModAttrPath(Application::GetLocalStateDir() + "/lib/icinga2/modified-attributes.conf");
-	Application::DeclareObjectsPath(Application::GetLocalStateDir() + "/cache/icinga2/icinga2.debug");
-	Application::DeclareVarsPath(Application::GetLocalStateDir() + "/cache/icinga2/icinga2.vars");
-	Application::DeclarePidPath(Application::GetRunDir() + "/icinga2/icinga2.pid");
+	Configuration::StatePath = Configuration::DataDir + "/icinga2.state";
+	Configuration::ModAttrPath = Configuration::DataDir + "/modified-attributes.conf";
+	Configuration::ObjectsPath = Configuration::CacheDir + "/icinga2.debug";
+	Configuration::VarsPath = Configuration::CacheDir + "/icinga2.vars";
+	Configuration::PidPath = Configuration::InitRunDir + "/icinga2.pid";
 
-	ConfigCompiler::AddIncludeSearchDir(Application::GetIncludeConfDir());
+	ConfigCompiler::AddIncludeSearchDir(Configuration::IncludeConfDir);
 
 	if (!autocomplete && vm.count("include")) {
 		for (const String& includePath : vm["include"].as<std::vector<std::string> >()) {
@@ -480,8 +586,8 @@ static int Main()
 				return 0;
 			}
 		} else if (command && command->GetImpersonationLevel() == ImpersonateIcinga) {
-			String group = Application::GetRunAsGroup();
-			String user = Application::GetRunAsUser();
+			String group = Configuration::RunAsGroup;
+			String user = Configuration::RunAsUser;
 
 			errno = 0;
 			struct group *gr = getgrnam(group.CStr());
