@@ -62,13 +62,14 @@ Value Array::Get(SizeType index) const
  *
  * @param index The index.
  * @param value The value.
+ * @param overrideFrozen Whether to allow modifying frozen arrays.
  */
-void Array::Set(SizeType index, const Value& value)
+void Array::Set(SizeType index, const Value& value, bool overrideFrozen)
 {
 	ObjectLock olock(this);
 
-	if (m_Frozen)
-		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
+	if (m_Frozen && !overrideFrozen)
+		BOOST_THROW_EXCEPTION(std::invalid_argument("Value in array must not be modified."));
 
 	m_Data.at(index) = value;
 }
@@ -78,12 +79,13 @@ void Array::Set(SizeType index, const Value& value)
  *
  * @param index The index.
  * @param value The value.
+ * @param overrideFrozen Whether to allow modifying frozen arrays.
  */
-void Array::Set(SizeType index, Value&& value)
+void Array::Set(SizeType index, Value&& value, bool overrideFrozen)
 {
 	ObjectLock olock(this);
 
-	if (m_Frozen)
+	if (m_Frozen && !overrideFrozen)
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
 
 	m_Data.at(index).Swap(value);
@@ -93,12 +95,13 @@ void Array::Set(SizeType index, Value&& value)
  * Adds a value to the array.
  *
  * @param value The value.
+ * @param overrideFrozen Whether to allow modifying frozen arrays.
  */
-void Array::Add(Value value)
+void Array::Add(Value value, bool overrideFrozen)
 {
 	ObjectLock olock(this);
 
-	if (m_Frozen)
+	if (m_Frozen && !overrideFrozen)
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
 
 	m_Data.push_back(std::move(value));
@@ -162,14 +165,15 @@ bool Array::Contains(const Value& value) const
  *
  * @param index The index
  * @param value The value to add
+ * @param overrideFrozen Whether to allow modifying frozen arrays.
  */
-void Array::Insert(SizeType index, Value value)
+void Array::Insert(SizeType index, Value value, bool overrideFrozen)
 {
 	ObjectLock olock(this);
 
 	ASSERT(index <= m_Data.size());
 
-	if (m_Frozen)
+	if (m_Frozen && !overrideFrozen)
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
 
 	m_Data.insert(m_Data.begin() + index, std::move(value));
@@ -179,12 +183,13 @@ void Array::Insert(SizeType index, Value value)
  * Removes the specified index from the array.
  *
  * @param index The index.
+ * @param overrideFrozen Whether to allow modifying frozen arrays.
  */
-void Array::Remove(SizeType index)
+void Array::Remove(SizeType index, bool overrideFrozen)
 {
 	ObjectLock olock(this);
 
-	if (m_Frozen)
+	if (m_Frozen && !overrideFrozen)
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
 
 	m_Data.erase(m_Data.begin() + index);
@@ -194,42 +199,43 @@ void Array::Remove(SizeType index)
  * Removes the item specified by the iterator from the array.
  *
  * @param it The iterator.
+ * @param overrideFrozen Whether to allow modifying frozen arrays.
  */
-void Array::Remove(Array::Iterator it)
+void Array::Remove(Array::Iterator it, bool overrideFrozen)
 {
 	ASSERT(OwnsLock());
 
-	if (m_Frozen)
+	if (m_Frozen && !overrideFrozen)
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
 
 	m_Data.erase(it);
 }
 
-void Array::Resize(SizeType newSize)
+void Array::Resize(SizeType newSize, bool overrideFrozen)
 {
 	ObjectLock olock(this);
 
-	if (m_Frozen)
+	if (m_Frozen && !overrideFrozen)
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
 
 	m_Data.resize(newSize);
 }
 
-void Array::Clear()
+void Array::Clear(bool overrideFrozen)
 {
 	ObjectLock olock(this);
 
-	if (m_Frozen)
+	if (m_Frozen && !overrideFrozen)
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
 
 	m_Data.clear();
 }
 
-void Array::Reserve(SizeType newSize)
+void Array::Reserve(SizeType newSize, bool overrideFrozen)
 {
 	ObjectLock olock(this);
 
-	if (m_Frozen)
+	if (m_Frozen && !overrideFrozen)
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
 
 	m_Data.reserve(newSize);
@@ -288,11 +294,11 @@ Array::Ptr Array::Reverse() const
 	return result;
 }
 
-void Array::Sort()
+void Array::Sort(bool overrideFrozen)
 {
 	ObjectLock olock(this);
 
-	if (m_Frozen)
+	if (m_Frozen && !overrideFrozen)
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Array must not be modified."));
 
 	std::sort(m_Data.begin(), m_Data.end());
@@ -342,7 +348,7 @@ Value Array::GetFieldByName(const String& field, bool sandboxed, const DebugInfo
 	return Get(index);
 }
 
-void Array::SetFieldByName(const String& field, const Value& value, const DebugInfo& debugInfo)
+void Array::SetFieldByName(const String& field, const Value& value, bool overrideFrozen, const DebugInfo& debugInfo)
 {
 	ObjectLock olock(this);
 
@@ -352,9 +358,9 @@ void Array::SetFieldByName(const String& field, const Value& value, const DebugI
 		BOOST_THROW_EXCEPTION(ScriptError("Array index '" + Convert::ToString(index) + "' is out of bounds.", debugInfo));
 
 	if (static_cast<size_t>(index) >= GetLength())
-		Resize(index + 1);
+		Resize(index + 1, overrideFrozen);
 
-	Set(index, value);
+	Set(index, value, overrideFrozen);
 }
 
 Array::Iterator icinga::begin(const Array::Ptr& x)
