@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -23,10 +23,6 @@
 
 using namespace icinga;
 
-DebugInfo::DebugInfo(void)
-	: FirstLine(0), FirstColumn(0), LastLine(0), LastColumn(0)
-{ }
-
 /**
  * Outputs a DebugInfo struct to a stream.
  *
@@ -37,9 +33,9 @@ DebugInfo::DebugInfo(void)
 std::ostream& icinga::operator<<(std::ostream& out, const DebugInfo& val)
 {
 	out << "in " << val.Path << ": "
-	    << val.FirstLine << ":" << val.FirstColumn
-	    << "-"
-	    << val.LastLine << ":" << val.LastColumn;
+		<< val.FirstLine << ":" << val.FirstColumn
+		<< "-"
+		<< val.LastLine << ":" << val.LastColumn;
 
 	return out;
 }
