@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -59,7 +59,7 @@ std::vector<Object::Ptr> DependencyGraph::GetParents(const Object::Ptr& child)
 	if (it != m_Dependencies.end()) {
 		typedef std::pair<Object *, int> kv_pair;
 		for (const kv_pair& kv : it->second) {
-			objects.push_back(kv.first);
+			objects.emplace_back(kv.first);
 		}
 	}
 
