@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -22,7 +22,7 @@
 
 using namespace icinga;
 
-bool icinga::InitializeOnceHelper(void (*func)(void), int priority)
+bool icinga::InitializeOnceHelper(void (*func)(), int priority)
 {
 	Loader::AddDeferredInitializer(func, priority);
 	return true;
