@@ -32,11 +32,15 @@ static String JsonEncodeShim(const Value& value)
 }
 
 INITIALIZE_ONCE([]() {
-	Dictionary::Ptr jsonObj = new Dictionary({
-		/* Methods */
-		{ "encode", new Function("Json#encode", JsonEncodeShim, { "value" }, true) },
-		{ "decode", new Function("Json#decode", JsonDecode, { "value" }, true) }
-	});
+	auto jsonNSBehavior = new ConstNamespaceBehavior();
+	Namespace::Ptr jsonNS = new Namespace(jsonNSBehavior);
 
-	ScriptGlobal::Set("Json", jsonObj);
+	/* Methods */
+	jsonNS->Set("encode", new Function("Json#encode", JsonEncodeShim, { "value" }, true));
+	jsonNS->Set("decode", new Function("Json#decode", JsonDecode, { "value" }, true));
+
+	jsonNSBehavior->Freeze();
+
+	Namespace::Ptr systemNS = ScriptGlobal::Get("System");
+	systemNS->SetAttribute("Json", std::make_shared<ConstEmbeddedNamespaceValue>(jsonNS));
 });
