@@ -22,6 +22,7 @@
 #include "base/functionwrapper.hpp"
 #include "base/scriptframe.hpp"
 #include "base/initialize.hpp"
+#include "base/namespace.hpp"
 #include <boost/math/special_functions/round.hpp>
 #include <cmath>
 
@@ -158,40 +159,44 @@ static double MathSign(double x)
 }
 
 INITIALIZE_ONCE([]() {
-	Dictionary::Ptr mathObj = new Dictionary({
-		/* Constants */
-		{ "E", 2.71828182845904523536 },
-		{ "LN2", 0.693147180559945309417 },
-		{ "LN10", 2.30258509299404568402 },
-		{ "LOG2E", 1.44269504088896340736 },
-		{ "LOG10E", 0.434294481903251827651 },
-		{ "PI", 3.14159265358979323846 },
-		{ "SQRT1_2", 0.707106781186547524401 },
-		{ "SQRT2", 1.41421356237309504880 },
+	auto mathNSBehavior = new ConstNamespaceBehavior();
+	Namespace::Ptr mathNS = new Namespace(mathNSBehavior);
 
-		/* Methods */
-		{ "abs", new Function("Math#abs", MathAbs, { "x" }, true) },
-		{ "acos", new Function("Math#acos", MathAcos, { "x" }, true) },
-		{ "asin", new Function("Math#asin", MathAsin, { "x" }, true) },
-		{ "atan", new Function("Math#atan", MathAtan, { "x" }, true) },
-		{ "atan2", new Function("Math#atan2", MathAtan2, { "x", "y" }, true) },
-		{ "ceil", new Function("Math#ceil", MathCeil, { "x" }, true) },
-		{ "cos", new Function("Math#cos", MathCos, { "x" }, true) },
-		{ "exp", new Function("Math#exp", MathExp, { "x" }, true) },
-		{ "floor", new Function("Math#floor", MathFloor, { "x" }, true) },
-		{ "log", new Function("Math#log", MathLog, { "x" }, true) },
-		{ "max", new Function("Math#max", MathMax, {}, true) },
-		{ "min", new Function("Math#min", MathMin, {}, true) },
-		{ "pow", new Function("Math#pow", MathPow, { "x", "y" }, true) },
-		{ "random", new Function("Math#random", MathRandom, {}, true) },
-		{ "round", new Function("Math#round", MathRound, { "x" }, true) },
-		{ "sin", new Function("Math#sin", MathSin, { "x" }, true) },
-		{ "sqrt", new Function("Math#sqrt", MathSqrt, { "x" }, true) },
-		{ "tan", new Function("Math#tan", MathTan, { "x" }, true) },
-		{ "isnan", new Function("Math#isnan", MathIsnan, { "x" }, true) },
-		{ "isinf", new Function("Math#isinf", MathIsinf, { "x" }, true) },
-		{ "sign", new Function("Math#sign", MathSign, { "x" }, true) }
-	});
+	/* Constants */
+	mathNS->Set("E", 2.71828182845904523536);
+	mathNS->Set("LN2", 0.693147180559945309417);
+	mathNS->Set("LN10", 2.30258509299404568402);
+	mathNS->Set("LOG2E", 1.44269504088896340736);
+	mathNS->Set("LOG10E", 0.434294481903251827651);
+	mathNS->Set("PI", 3.14159265358979323846);
+	mathNS->Set("SQRT1_2", 0.707106781186547524401);
+	mathNS->Set("SQRT2", 1.41421356237309504880);
 
-	ScriptGlobal::Set("Math", mathObj);
+	/* Methods */
+	mathNS->Set("abs", new Function("Math#abs", MathAbs, { "x" }, true));
+	mathNS->Set("acos", new Function("Math#acos", MathAcos, { "x" }, true));
+	mathNS->Set("asin", new Function("Math#asin", MathAsin, { "x" }, true));
+	mathNS->Set("atan", new Function("Math#atan", MathAtan, { "x" }, true));
+	mathNS->Set("atan2", new Function("Math#atan2", MathAtan2, { "x", "y" }, true));
+	mathNS->Set("ceil", new Function("Math#ceil", MathCeil, { "x" }, true));
+	mathNS->Set("cos", new Function("Math#cos", MathCos, { "x" }, true));
+	mathNS->Set("exp", new Function("Math#exp", MathExp, { "x" }, true));
+	mathNS->Set("floor", new Function("Math#floor", MathFloor, { "x" }, true));
+	mathNS->Set("log", new Function("Math#log", MathLog, { "x" }, true));
+	mathNS->Set("max", new Function("Math#max", MathMax, {}, true));
+	mathNS->Set("min", new Function("Math#min", MathMin, {}, true));
+	mathNS->Set("pow", new Function("Math#pow", MathPow, { "x", "y" }, true));
+	mathNS->Set("random", new Function("Math#random", MathRandom, {}, true));
+	mathNS->Set("round", new Function("Math#round", MathRound, { "x" }, true));
+	mathNS->Set("sin", new Function("Math#sin", MathSin, { "x" }, true));
+	mathNS->Set("sqrt", new Function("Math#sqrt", MathSqrt, { "x" }, true));
+	mathNS->Set("tan", new Function("Math#tan", MathTan, { "x" }, true));
+	mathNS->Set("isnan", new Function("Math#isnan", MathIsnan, { "x" }, true));
+	mathNS->Set("isinf", new Function("Math#isinf", MathIsinf, { "x" }, true));
+	mathNS->Set("sign", new Function("Math#sign", MathSign, { "x" }, true));
+
+	mathNSBehavior->Freeze();
+
+	Namespace::Ptr systemNS = ScriptGlobal::Get("System");
+	systemNS->SetAttribute("Math", std::make_shared<ConstEmbeddedNamespaceValue>(mathNS));
 });
