@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -25,7 +25,7 @@
 
 using namespace icinga;
 
-static String ObjectToString(void)
+static String ObjectToString()
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
 	Object::Ptr self = static_cast<Object::Ptr>(vframe->Self);
@@ -41,7 +41,7 @@ static void ObjectNotifyAttribute(const String& attribute)
 	self->NotifyField(self->GetReflectionType()->GetFieldId(attribute));
 }
 
-static Object::Ptr ObjectClone(void)
+static Object::Ptr ObjectClone()
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
 	Object::Ptr self = static_cast<Object::Ptr>(vframe->Self);
@@ -49,16 +49,13 @@ static Object::Ptr ObjectClone(void)
 	return self->Clone();
 }
 
-Object::Ptr Object::GetPrototype(void)
+Object::Ptr Object::GetPrototype()
 {
-	static Dictionary::Ptr prototype;
-
-	if (!prototype) {
-		prototype = new Dictionary();
-		prototype->Set("to_string", new Function("Object#to_string", WrapFunction(ObjectToString), {}, true));
-		prototype->Set("notify_attribute", new Function("Object#notify_attribute", WrapFunction(ObjectNotifyAttribute), { "attribute" }, false));
-		prototype->Set("clone", new Function("Object#clone", WrapFunction(ObjectClone), {}, true));
-	}
+	static Dictionary::Ptr prototype = new Dictionary({
+			{ "to_string", new Function("Object#to_string", ObjectToString, {}, true) },
+			{ "notify_attribute", new Function("Object#notify_attribute", ObjectNotifyAttribute, { "attribute" }, false) },
+			{ "clone", new Function("Object#clone", ObjectClone, {}, true) }
+	});
 
 	return prototype;
 }
