@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -35,22 +35,11 @@ template<typename T>
 class Singleton
 {
 public:
-	static T *GetInstance(void)
+	static T *GetInstance()
 	{
-		/* FIXME: This relies on static initializers being atomic. */
-		static boost::mutex mutex;
-		boost::mutex::scoped_lock lock(mutex);
-
-		static T *instance;
-
-		if (!instance)
-			instance = new T();
-
-		return instance;
+		static T instance;
+		return &instance;
 	}
-
-private:
-	static T *m_Instance;
 };
 
 }
