@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -22,7 +22,7 @@
 
 using namespace icinga;
 
-void Stream::RegisterDataHandler(const boost::function<void(const Stream::Ptr&)>& handler)
+void Stream::RegisterDataHandler(const std::function<void(const Stream::Ptr&)>& handler)
 {
 	if (SupportsWaiting())
 		OnDataAvailable.connect(handler);
@@ -30,17 +30,17 @@ void Stream::RegisterDataHandler(const boost::function<void(const Stream::Ptr&)>
 		BOOST_THROW_EXCEPTION(std::runtime_error("Stream does not support waiting."));
 }
 
-bool Stream::SupportsWaiting(void) const
+bool Stream::SupportsWaiting() const
 {
 	return false;
 }
 
-bool Stream::IsDataAvailable(void) const
+bool Stream::IsDataAvailable() const
 {
 	return false;
 }
 
-void Stream::Shutdown(void)
+void Stream::Shutdown()
 {
 	BOOST_THROW_EXCEPTION(std::runtime_error("Stream does not support Shutdown()."));
 }
@@ -50,7 +50,7 @@ size_t Stream::Peek(void *buffer, size_t count, bool allow_partial)
 	BOOST_THROW_EXCEPTION(std::runtime_error("Stream does not support Peek()."));
 }
 
-void Stream::SignalDataAvailable(void)
+void Stream::SignalDataAvailable()
 {
 	OnDataAvailable(this);
 
@@ -60,7 +60,7 @@ void Stream::SignalDataAvailable(void)
 	}
 }
 
-bool Stream::WaitForData(void)
+bool Stream::WaitForData()
 {
 	if (!SupportsWaiting())
 		BOOST_THROW_EXCEPTION(std::runtime_error("Stream does not support waiting."));
@@ -91,26 +91,26 @@ bool Stream::WaitForData(int timeout)
 	return IsDataAvailable() || IsEof();
 }
 
-static void StreamDummyCallback(void)
-{ }
-
 void Stream::SetCorked(bool corked)
 {
 	m_Corked = corked;
 }
 
-bool Stream::IsCorked(void) const
+bool Stream::IsCorked() const
 {
 	return m_Corked;
 }
 
-void Stream::Close(void)
+static void StreamDummyCallback()
+{ }
+
+void Stream::Close()
 {
 	OnDataAvailable.disconnect_all_slots();
 
 	/* Force signals2 to remove the slots, see https://stackoverflow.com/questions/2049291/force-deletion-of-slot-in-boostsignals2
 	 * for details. */
-	OnDataAvailable.connect(boost::bind(&StreamDummyCallback));
+	OnDataAvailable.connect(std::bind(&StreamDummyCallback));
 }
 
 StreamReadStatus Stream::ReadLine(String *line, StreamReadContext& context, bool may_wait)
@@ -129,31 +129,19 @@ StreamReadStatus Stream::ReadLine(String *line, StreamReadContext& context, bool
 		}
 	}
 
-	int count = 0;
-	size_t first_newline;
-
 	for (size_t i = 0; i < context.Size; i++) {
 		if (context.Buffer[i] == '\n') {
-			count++;
+			*line = String(context.Buffer, context.Buffer + i);
+			boost::algorithm::trim_right(*line);
 
-			if (count == 1)
-				first_newline = i;
-			else if (count > 1)
-				break;
+			context.DropData(i + 1u);
+
+			context.MustRead = !context.Size;
+			return StatusNewItem;
 		}
 	}
 
-	context.MustRead = (count <= 1);
-
-	if (count > 0) {
-		*line = String(context.Buffer, &(context.Buffer[first_newline]));
-		boost::algorithm::trim_right(*line);
-
-		context.DropData(first_newline + 1);
-
-		return StatusNewItem;
-	}
-
+	context.MustRead = true;
 	return StatusNeedData;
 }
 
