@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -23,6 +23,8 @@
 #include "base/i2-base.hpp"
 #include "base/object.hpp"
 #include <boost/signals2.hpp>
+#include <boost/thread/mutex.hpp>
+#include <boost/thread/condition_variable.hpp>
 
 namespace icinga
 {
@@ -36,13 +38,9 @@ enum ConnectionRole
 	RoleServer
 };
 
-struct I2_BASE_API StreamReadContext
+struct StreamReadContext
 {
-	StreamReadContext(void)
-		: Buffer(NULL), Size(0), MustRead(true), Eof(false)
-	{ }
-
-	~StreamReadContext(void)
+	~StreamReadContext()
 	{
 		free(Buffer);
 	}
@@ -50,10 +48,10 @@ struct I2_BASE_API StreamReadContext
 	bool FillFromStream(const intrusive_ptr<Stream>& stream, bool may_wait);
 	void DropData(size_t count);
 
-	char *Buffer;
-	size_t Size;
-	bool MustRead;
-	bool Eof;
+	char *Buffer{nullptr};
+	size_t Size{0};
+	bool MustRead{true};
+	bool Eof{false};
 };
 
 enum StreamReadStatus
@@ -68,7 +66,7 @@ enum StreamReadStatus
  *
  * @ingroup base
  */
-class I2_BASE_API Stream : public Object
+class Stream : public Object
 {
 public:
 	DECLARE_PTR_TYPEDEFS(Stream);
@@ -76,7 +74,7 @@ public:
 	/**
 	 * Reads data from the stream without removing it from the stream buffer.
 	 *
-	 * @param buffer The buffer where data should be stored. May be NULL if you're
+	 * @param buffer The buffer where data should be stored. May be nullptr if you're
 	 *		 not actually interested in the data.
 	 * @param count The number of bytes to read from the queue.
 	 * @param allow_partial Whether to allow partial reads.
@@ -87,7 +85,7 @@ public:
 	/**
 	 * Reads data from the stream.
 	 *
-	 * @param buffer The buffer where data should be stored. May be NULL if you're
+	 * @param buffer The buffer where data should be stored. May be nullptr if you're
 	 *		 not actually interested in the data.
 	 * @param count The number of bytes to read from the queue.
 	 * @param allow_partial Whether to allow partial reads.
@@ -108,19 +106,19 @@ public:
 	 * Causes the stream to be closed (via Close()) once all pending data has been
 	 * written.
 	 */
-	virtual void Shutdown(void);
+	virtual void Shutdown();
 
 	/**
 	 * Closes the stream and releases resources.
 	 */
-	virtual void Close(void);
+	virtual void Close();
 
 	/**
 	 * Checks whether we've reached the end-of-file condition.
 	 *
 	 * @returns true if EOF.
 	 */
-	virtual bool IsEof(void) const = 0;
+	virtual bool IsEof() const = 0;
 
 	/**
 	 * Waits until data can be read from the stream.
@@ -129,19 +127,19 @@ public:
 	bool WaitForData();
 	bool WaitForData(int timeout);
 
-	virtual bool SupportsWaiting(void) const;
-
 	virtual void SetCorked(bool corked);
-	bool IsCorked(void) const;
+	bool IsCorked() const;
 
-	virtual bool IsDataAvailable(void) const;
+	virtual bool SupportsWaiting() const;
 
-	void RegisterDataHandler(const boost::function<void(const Stream::Ptr&)>& handler);
+	virtual bool IsDataAvailable() const;
+
+	void RegisterDataHandler(const std::function<void(const Stream::Ptr&)>& handler);
 
 	StreamReadStatus ReadLine(String *line, StreamReadContext& context, bool may_wait = false);
 
 protected:
-	void SignalDataAvailable(void);
+	void SignalDataAvailable();
 
 private:
 	boost::signals2::signal<void(const Stream::Ptr&)> OnDataAvailable;
