@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -27,14 +27,14 @@
 
 using namespace icinga;
 
-static int StringLen(void)
+static int StringLen()
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
 	String self = vframe->Self;
 	return self.GetLength();
 }
 
-static String StringToString(void)
+static String StringToString()
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
 	return vframe->Self;
@@ -57,14 +57,14 @@ static String StringSubstr(const std::vector<Value>& args)
 		return self.SubStr(args[0]);
 }
 
-static String StringUpper(void)
+static String StringUpper()
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
 	String self = vframe->Self;
 	return boost::to_upper_copy(self);
 }
 
-static String StringLower(void)
+static String StringLower()
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
 	String self = vframe->Self;
@@ -75,14 +75,9 @@ static Array::Ptr StringSplit(const String& delims)
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
 	String self = vframe->Self;
-	std::vector<String> tokens;
-	boost::algorithm::split(tokens, self, boost::is_any_of(delims));
+	std::vector<String> tokens = self.Split(delims.CStr());
 
-	Array::Ptr result = new Array();
-	for (const String& token : tokens) {
-		result->Add(token);
-	}
-	return result;
+	return Array::FromVector(tokens);
 }
 
 static int StringFind(const std::vector<Value>& args)
@@ -125,38 +120,35 @@ static Value StringReplace(const String& search, const String& replacement)
 	return self;
 }
 
-static String StringReverse(void)
+static String StringReverse()
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
 	String self = vframe->Self;
 	return self.Reverse();
 }
 
-static String StringTrim(void)
+static String StringTrim()
 {
 	ScriptFrame *vframe = ScriptFrame::GetCurrentFrame();
 	String self = vframe->Self;
 	return self.Trim();
 }
 
-Object::Ptr String::GetPrototype(void)
+Object::Ptr String::GetPrototype()
 {
-	static Dictionary::Ptr prototype;
-
-	if (!prototype) {
-		prototype = new Dictionary();
-		prototype->Set("len", new Function("String#len", WrapFunction(StringLen), {}, true));
-		prototype->Set("to_string", new Function("String#to_string", WrapFunction(StringToString), {}, true));
-		prototype->Set("substr", new Function("String#substr", WrapFunction(StringSubstr), { "start", "len" }, true));
-		prototype->Set("upper", new Function("String#upper", WrapFunction(StringUpper), {}, true));
-		prototype->Set("lower", new Function("String#lower", WrapFunction(StringLower), {}, true));
-		prototype->Set("split", new Function("String#split", WrapFunction(StringSplit), { "delims" }, true));
-		prototype->Set("find", new Function("String#find", WrapFunction(StringFind), { "str", "start" }, true));
-		prototype->Set("contains", new Function("String#contains", WrapFunction(StringContains), { "str" }, true));
-		prototype->Set("replace", new Function("String#replace", WrapFunction(StringReplace), { "search", "replacement" }, true));
-		prototype->Set("reverse", new Function("String#reverse", WrapFunction(StringReverse), {}, true));
-		prototype->Set("trim", new Function("String#trim", WrapFunction(StringTrim), {}, true));
-	}
+	static Dictionary::Ptr prototype = new Dictionary({
+		{ "len", new Function("String#len", StringLen, {}, true) },
+		{ "to_string", new Function("String#to_string", StringToString, {}, true) },
+		{ "substr", new Function("String#substr", StringSubstr, { "start", "len" }, true) },
+		{ "upper", new Function("String#upper", StringUpper, {}, true) },
+		{ "lower", new Function("String#lower", StringLower, {}, true) },
+		{ "split", new Function("String#split", StringSplit, { "delims" }, true) },
+		{ "find", new Function("String#find", StringFind, { "str", "start" }, true) },
+		{ "contains", new Function("String#contains", StringContains, { "str" }, true) },
+		{ "replace", new Function("String#replace", StringReplace, { "search", "replacement" }, true) },
+		{ "reverse", new Function("String#reverse", StringReverse, {}, true) },
+		{ "trim", new Function("String#trim", StringTrim, {}, true) }
+	});
 
 	return prototype;
 }
