@@ -40,7 +40,10 @@ public:
 
 	~Timer() override;
 
+	static void Initialize();
 	static void Uninitialize();
+	static void InitializeThread();
+	static void UninitializeThread();
 
 	void SetInterval(double interval);
 	double GetInterval() const;
