@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -28,7 +28,7 @@
 
 using namespace icinga;
 
-Value::operator double(void) const
+Value::operator double() const
 {
 	const double *value = boost::get<double>(&m_Value);
 
@@ -52,7 +52,7 @@ Value::operator double(void) const
 	}
 }
 
-Value::operator String(void) const
+Value::operator String() const
 {
 	Object *object;
 
@@ -285,7 +285,7 @@ Value icinga::operator-(const Value& lhs, const Value& rhs)
 		if (lhs.IsEmpty())
 			return new Array();
 
-		Array::Ptr result = new Array();
+		ArrayData result;
 		Array::Ptr left = lhs;
 		Array::Ptr right = rhs;
 
@@ -303,10 +303,10 @@ Value icinga::operator-(const Value& lhs, const Value& rhs)
 			if (found)
 				continue;
 
-			result->Add(lv);
+			result.push_back(lv);
 		}
 
-		return result;
+		return new Array(std::move(result));
 	} else
 		BOOST_THROW_EXCEPTION(std::invalid_argument("Operator - cannot be applied to values of type '" + lhs.GetTypeName() + "' and '" + rhs.GetTypeName() + "'"));
 }
