@@ -40,7 +40,7 @@ using namespace icinga;
 
 String ApiSetupUtility::GetConfdPath()
 {
-	return Application::GetSysconfDir() + "/icinga2/conf.d";
+	return Configuration::ConfigDir + "/conf.d";
 }
 
 String ApiSetupUtility::GetApiUsersConfPath()
@@ -80,8 +80,8 @@ bool ApiSetupUtility::SetupMasterCertificates(const String& cn)
 	String pki_path = ApiListener::GetCertsDir();
 	Utility::MkDirP(pki_path, 0700);
 
-	String user = ScriptGlobal::Get("RunAsUser");
-	String group = ScriptGlobal::Get("RunAsGroup");
+	String user = Configuration::RunAsUser;
+	String group = Configuration::RunAsGroup;
 
 	if (!Utility::SetFileOwnership(pki_path, user, group)) {
 		Log(LogWarning, "cli")
@@ -171,7 +171,7 @@ bool ApiSetupUtility::SetupMasterApiUser()
 	String tempFilename = Utility::CreateTempFile(apiUsersPath + ".XXXXXX", 0644, fp);
 
 	fp << "/**\n"
-		<< " * The APIUser objects are used for authentication against the API.\n"
+		<< " * The ApiUser objects are used for authentication against the API.\n"
 		<< " */\n"
 		<< "object ApiUser \"" << api_username << "\" {\n"
 		<< "  password = \"" << api_password << "\"\n"
