@@ -52,14 +52,28 @@ static void SigHupHandler(int)
 }
 #endif /* _WIN32 */
 
-static bool Daemonize()
+/*
+ * Daemonize().  On error, this function logs by itself and exits (i.e. does not return).
+ *
+ * Implementation note: We're only supposed to call exit() in one of the forked processes.
+ * The other process calls _exit().  This prevents issues with exit handlers like atexit().
+ */
+static void Daemonize() noexcept
 {
 #ifndef _WIN32
-	Application::UninitializeBase();
+	try {
+		Application::UninitializeBase();
+	} catch (const std::exception& ex) {
+		Log(LogCritical, "cli")
+			<< "Failed to stop thread pool before daemonizing, unexpected error: " << DiagnosticInformation(ex);
+		exit(EXIT_FAILURE);
+	}
 
 	pid_t pid = fork();
 	if (pid == -1) {
-		return false;
+		Log(LogCritical, "cli")
+			<< "fork() failed with error code " << errno << ", \"" << Utility::FormatErrorNumber(errno) << "\"";
+		exit(EXIT_FAILURE);
 	}
 
 	if (pid) {
@@ -72,7 +86,7 @@ static bool Daemonize()
 		do {
 			Utility::Sleep(0.1);
 
-			readpid = Application::ReadPidFile(Application::GetPidPath());
+			readpid = Application::ReadPidFile(Configuration::PidPath);
 			ret = waitpid(pid, &status, WNOHANG);
 		} while (readpid != pid && ret == 0);
 
@@ -88,13 +102,28 @@ static bool Daemonize()
 		_exit(EXIT_SUCCESS);
 	}
 
-	Application::InitializeBase();
-#endif /* _WIN32 */
+	Log(LogDebug, "Daemonize()")
+		<< "Child process with PID " << Utility::GetPid() << " continues; re-initializing base.";
 
-	return true;
+	// Detach from controlling terminal
+	pid_t sid = setsid();
+	if (sid == -1) {
+		Log(LogCritical, "cli")
+			<< "setsid() failed with error code " << errno << ", \"" << Utility::FormatErrorNumber(errno) << "\"";
+		exit(EXIT_FAILURE);
+	}
+
+	try {
+		Application::InitializeBase();
+	} catch (const std::exception& ex) {
+		Log(LogCritical, "cli")
+			<< "Failed to re-initialize thread pool after daemonizing: " << DiagnosticInformation(ex);
+		exit(EXIT_FAILURE);
+	}
+#endif /* _WIN32 */
 }
 
-static bool SetDaemonIO(const String& stderrFile)
+static void CloseStdIO(const String& stderrFile)
 {
 #ifndef _WIN32
 	int fdnull = open("/dev/null", O_RDWR);
@@ -126,14 +155,7 @@ static bool SetDaemonIO(const String& stderrFile)
 		if (fderr > 2)
 			close(fderr);
 	}
-
-	pid_t sid = setsid();
-	if (sid == -1) {
-		return false;
-	}
 #endif
-
-	return true;
 }
 
 String DaemonCommand::GetDescription() const
@@ -153,9 +175,10 @@ void DaemonCommand::InitParameters(boost::program_options::options_description&
 		("config,c", po::value<std::vector<std::string> >(), "parse a configuration file")
 		("no-config,z", "start without a configuration file")
 		("validate,C", "exit after validating the configuration")
-		("errorlog,e", po::value<std::string>(), "log fatal errors to the specified log file (only works in combination with --daemonize)")
+		("errorlog,e", po::value<std::string>(), "log fatal errors to the specified log file (only works in combination with --daemonize or --close-stdio)")
 #ifndef _WIN32
 		("daemonize,d", "detach from the controlling terminal")
+		("close-stdio", "do not log to stdout (or stderr) after startup")
 #endif /* _WIN32 */
 	;
 
@@ -190,7 +213,7 @@ int DaemonCommand::Run(const po::variables_map& vm, const std::vector<std::strin
 		<< ")";
 
 	if (!vm.count("validate") && !vm.count("reload-internal")) {
-		pid_t runningpid = Application::ReadPidFile(Application::GetPidPath());
+		pid_t runningpid = Application::ReadPidFile(Configuration::PidPath);
 		if (runningpid > 0) {
 			Log(LogCritical, "cli")
 				<< "Another instance of Icinga already running with PID " << runningpid;
@@ -201,14 +224,17 @@ int DaemonCommand::Run(const po::variables_map& vm, const std::vector<std::strin
 	std::vector<std::string> configs;
 	if (vm.count("config") > 0)
 		configs = vm["config"].as<std::vector<std::string> >();
-	else if (!vm.count("no-config"))
-		configs.push_back(Application::GetSysconfDir() + "/icinga2/icinga2.conf");
+	else if (!vm.count("no-config")) {
+		/* The implicit string assignment is needed for Windows builds. */
+		String configDir = Configuration::ConfigDir;
+		configs.push_back(configDir + "/icinga2.conf");
+	}
 
 	Log(LogInformation, "cli", "Loading configuration file(s).");
 
 	std::vector<ConfigItem::Ptr> newItems;
 
-	if (!DaemonUtility::LoadConfigFiles(configs, newItems, Application::GetObjectsPath(), Application::GetVarsPath()))
+	if (!DaemonUtility::LoadConfigFiles(configs, newItems, Configuration::ObjectsPath, Configuration::VarsPath))
 		return EXIT_FAILURE;
 
 	if (vm.count("validate")) {
@@ -239,18 +265,16 @@ int DaemonCommand::Run(const po::variables_map& vm, const std::vector<std::strin
 	if (vm.count("daemonize")) {
 		if (!vm.count("reload-internal")) {
 			// no additional fork neccessary on reload
-			try {
-				Daemonize();
-			} catch (std::exception&) {
-				Log(LogCritical, "cli", "Daemonize failed. Exiting.");
-				return EXIT_FAILURE;
-			}
+
+			// this subroutine either succeeds, or logs an error
+			// and terminates the process (does not return).
+			Daemonize();
 		}
 	}
 
 	/* restore the previous program state */
 	try {
-		ConfigObject::RestoreObjects(Application::GetStatePath());
+		ConfigObject::RestoreObjects(Configuration::StatePath);
 	} catch (const std::exception& ex) {
 		Log(LogCritical, "cli")
 			<< "Failed to restore state file: " << DiagnosticInformation(ex);
@@ -258,7 +282,7 @@ int DaemonCommand::Run(const po::variables_map& vm, const std::vector<std::strin
 	}
 
 	{
-		WorkQueue upq(25000, Application::GetConcurrency());
+		WorkQueue upq(25000, Configuration::Concurrency);
 		upq.SetName("DaemonCommand::Run");
 
 		// activate config only after daemonization: it starts threads and that is not compatible with fork()
@@ -268,12 +292,16 @@ int DaemonCommand::Run(const po::variables_map& vm, const std::vector<std::strin
 		}
 	}
 
-	if (vm.count("daemonize")) {
+	if (vm.count("daemonize") || vm.count("close-stdio")) {
+		// After disabling the console log, any further errors will go to the configured log only.
+		// Let's try to make this clear and say good bye.
+		Log(LogInformation, "cli", "Closing console log.");
+
 		String errorLog;
 		if (vm.count("errorlog"))
 			errorLog = vm["errorlog"].as<std::string>();
 
-		SetDaemonIO(errorLog);
+		CloseStdIO(errorLog);
 		Logger::DisableConsoleLog();
 	}
 
