@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -31,12 +31,12 @@ namespace icinga
 /**
  * @ingroup cli
  */
-class I2_CLI_API DaemonUtility
+class DaemonUtility
 {
 public:
 	static bool ValidateConfigFiles(const std::vector<std::string>& configs, const String& objectsFile = String());
 	static bool LoadConfigFiles(const std::vector<std::string>& configs, std::vector<ConfigItem::Ptr>& newItems,
-	    const String& objectsFile = String(), const String& varsfile = String());
+		const String& objectsFile = String(), const String& varsfile = String());
 };
 
 }
