@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -30,18 +30,18 @@ namespace icinga
  *
  * @ingroup cli
  */
-class FeatureDisableCommand : public CLICommand
+class FeatureDisableCommand final : public CLICommand
 {
 public:
 	DECLARE_PTR_TYPEDEFS(FeatureDisableCommand);
 
-	virtual String GetDescription(void) const override;
-	virtual String GetShortDescription(void) const override;
-	virtual int GetMinArguments(void) const override;
-	virtual int GetMaxArguments(void) const override;
-	virtual std::vector<String> GetPositionalSuggestions(const String& word) const override;
-	virtual ImpersonationLevel GetImpersonationLevel(void) const override;
-	virtual int Run(const boost::program_options::variables_map& vm, const std::vector<std::string>& ap) const override;
+	String GetDescription() const override;
+	String GetShortDescription() const override;
+	int GetMinArguments() const override;
+	int GetMaxArguments() const override;
+	std::vector<String> GetPositionalSuggestions(const String& word) const override;
+	ImpersonationLevel GetImpersonationLevel() const override;
+	int Run(const boost::program_options::variables_map& vm, const std::vector<std::string>& ap) const override;
 
 };
 
