@@ -121,12 +121,6 @@ int NodeSetupCommand::SetupMaster(const boost::program_options::variables_map& v
 	if (vm.count("trustedcert"))
 		Log(LogWarning, "cli", "Master for Node setup: Ignoring --trustedcert");
 
-	if (vm.count("accept-config"))
-		Log(LogWarning, "cli", "Master for Node setup: Ignoring --accept-config");
-
-	if (vm.count("accept-commands"))
-		Log(LogWarning, "cli", "Master for Node setup: Ignoring --accept-commands");
-
 	String cn = Utility::GetFQDN();
 
 	if (vm.count("cn"))
@@ -212,6 +206,18 @@ int NodeSetupCommand::SetupMaster(const boost::program_options::variables_map& v
 			fp << "  bind_port = " << tokens[1] << "\n";
 	}
 
+	fp << "\n";
+
+	if (vm.count("accept-config"))
+		fp << "  accept_config = true\n";
+	else
+		fp << "  accept_config = false\n";
+
+	if (vm.count("accept-commands"))
+		fp << "  accept_commands = true\n";
+	else
+		fp << "  accept_commands = false\n";
+
 	fp << "\n"
 		<< "  ticket_salt = TicketSalt\n"
 		<< "}\n";
@@ -262,7 +268,7 @@ int NodeSetupCommand::SetupMaster(const boost::program_options::variables_map& v
 			NodeUtility::UpdateConfiguration("\"conf.d/api-users.conf\"", true, false);
 		} else {
 			Log(LogWarning, "cli")
-				<< "Included file dosen't exist " << apiUsersFilePath;
+				<< "Included file doesn't exist " << apiUsersFilePath;
 		}
 	}
 
@@ -353,8 +359,8 @@ int NodeSetupCommand::SetupNode(const boost::program_options::variables_map& vm,
 	String certsDir = ApiListener::GetCertsDir();
 	Utility::MkDirP(certsDir, 0700);
 
-	String user = ScriptGlobal::Get("RunAsUser");
-	String group = ScriptGlobal::Get("RunAsGroup");
+	String user = Configuration::RunAsUser;
+	String group = Configuration::RunAsGroup;
 
 	if (!Utility::SetFileOwnership(certsDir, user, group)) {
 		Log(LogWarning, "cli")
@@ -410,7 +416,7 @@ int NodeSetupCommand::SetupNode(const boost::program_options::variables_map& vm,
 	} else {
 		/* We cannot retrieve the parent certificate.
 		 * Tell the user to manually copy the ca.crt file
-		 * into LocalStateDir + "/lib/icinga2/certs"
+		 * into DataDir + "/certs"
 		 */
 		Log(LogWarning, "cli")
 			<< "\nNo connection to the parent node was specified.\n\n"
