@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -25,12 +25,12 @@ using namespace icinga;
 
 REGISTER_CLICOMMAND("pki/new-ca", PKINewCACommand);
 
-String PKINewCACommand::GetDescription(void) const
+String PKINewCACommand::GetDescription() const
 {
 	return "Sets up a new Certificate Authority.";
 }
 
-String PKINewCACommand::GetShortDescription(void) const
+String PKINewCACommand::GetShortDescription() const
 {
 	return "sets up a new CA";
 }
