@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -26,18 +26,18 @@ namespace po = boost::program_options;
 
 REGISTER_CLICOMMAND("pki/new-cert", PKINewCertCommand);
 
-String PKINewCertCommand::GetDescription(void) const
+String PKINewCertCommand::GetDescription() const
 {
 	return "Creates a new Certificate Signing Request, a self-signed X509 certificate or both.";
 }
 
-String PKINewCertCommand::GetShortDescription(void) const
+String PKINewCertCommand::GetShortDescription() const
 {
 	return "creates a new CSR";
 }
 
 void PKINewCertCommand::InitParameters(boost::program_options::options_description& visibleDesc,
-    boost::program_options::options_description& hiddenDesc) const
+	boost::program_options::options_description& hiddenDesc) const
 {
 	visibleDesc.add_options()
 		("cn", po::value<std::string>(), "Common Name")
