@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -28,22 +28,22 @@ namespace po = boost::program_options;
 
 REGISTER_CLICOMMAND("pki/ticket", PKITicketCommand);
 
-String PKITicketCommand::GetDescription(void) const
+String PKITicketCommand::GetDescription() const
 {
 	return "Generates an Icinga 2 ticket";
 }
 
-String PKITicketCommand::GetShortDescription(void) const
+String PKITicketCommand::GetShortDescription() const
 {
 	return "generates a ticket";
 }
 
 void PKITicketCommand::InitParameters(boost::program_options::options_description& visibleDesc,
-    boost::program_options::options_description& hiddenDesc) const
+	boost::program_options::options_description& hiddenDesc) const
 {
 	visibleDesc.add_options()
-	    ("cn", po::value<std::string>(), "Certificate common name")
-	    ("salt", po::value<std::string>(), "Ticket salt");
+		("cn", po::value<std::string>(), "Certificate common name")
+		("salt", po::value<std::string>(), "Ticket salt");
 }
 
 /**
