@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -32,14 +32,14 @@ namespace icinga
 /**
  * @ingroup cli
  */
-class I2_CLI_API VariableUtility
+class VariableUtility
 {
 public:
 	static Value GetVariable(const String& name);
 	static void PrintVariables(std::ostream& outfp);
 
 private:
-	VariableUtility(void);
+	VariableUtility();
 
 };
 
