@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -20,7 +20,7 @@
 #ifndef CHECKRESULTREADER_H
 #define CHECKRESULTREADER_H
 
-#include "compat/checkresultreader.thpp"
+#include "compat/checkresultreader-ti.hpp"
 #include "base/timer.hpp"
 #include <fstream>
 
@@ -32,7 +32,7 @@ namespace icinga
  *
  * @ingroup compat
  */
-class CheckResultReader : public ObjectImpl<CheckResultReader>
+class CheckResultReader final : public ObjectImpl<CheckResultReader>
 {
 public:
 	DECLARE_OBJECT(CheckResultReader);
@@ -41,12 +41,12 @@ public:
 	static void StatsFunc(const Dictionary::Ptr& status, const Array::Ptr& perfdata);
 
 protected:
-	virtual void Start(bool runtimeCreated) override;
-	virtual void Stop(bool runtimeRemoved) override;
+	void Start(bool runtimeCreated) override;
+	void Stop(bool runtimeRemoved) override;
 
 private:
 	Timer::Ptr m_ReadTimer;
-	void ReadTimerHandler(void) const;
+	void ReadTimerHandler() const;
 	void ProcessCheckResultFile(const String& path) const;
 };
 
