@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -20,7 +20,7 @@
 #ifndef COMPATLOGGER_H
 #define COMPATLOGGER_H
 
-#include "compat/compatlogger.thpp"
+#include "compat/compatlogger-ti.hpp"
 #include "icinga/service.hpp"
 #include "base/timer.hpp"
 #include <fstream>
@@ -33,7 +33,7 @@ namespace icinga
  *
  * @ingroup compat
  */
-class CompatLogger : public ObjectImpl<CompatLogger>
+class CompatLogger final : public ObjectImpl<CompatLogger>
 {
 public:
 	DECLARE_OBJECT(CompatLogger);
@@ -41,20 +41,20 @@ public:
 
 	static void StatsFunc(const Dictionary::Ptr& status, const Array::Ptr& perfdata);
 
-	virtual void ValidateRotationMethod(const String& value, const ValidationUtils& utils) override;
+	void ValidateRotationMethod(const Lazy<String>& lvalue, const ValidationUtils& utils) override;
 
 protected:
-	virtual void Start(bool runtimeCreated) override;
-	virtual void Stop(bool runtimeRemoved) override;
+	void Start(bool runtimeCreated) override;
+	void Stop(bool runtimeRemoved) override;
 
 private:
 	void WriteLine(const String& line);
-	void Flush(void);
+	void Flush();
 
 	void CheckResultHandler(const Checkable::Ptr& service, const CheckResult::Ptr& cr);
 	void NotificationSentHandler(const Notification::Ptr& notification, const Checkable::Ptr& service,
-	    const User::Ptr& user, NotificationType notification_type, CheckResult::Ptr const& cr,
-	    const String& author, const String& comment_text, const String& command_name);
+		const User::Ptr& user, NotificationType notification_type, CheckResult::Ptr const& cr,
+		const String& author, const String& comment_text, const String& command_name);
 	void FlappingChangedHandler(const Checkable::Ptr& checkable);
 	void EnableFlappingChangedHandler(const Checkable::Ptr& checkable);
 	void TriggerDowntimeHandler(const Downtime::Ptr& downtime);
@@ -62,9 +62,11 @@ private:
 	void ExternalCommandHandler(const String& command, const std::vector<String>& arguments);
 	void EventCommandHandler(const Checkable::Ptr& service);
 
+	static String GetHostStateString(const Host::Ptr& host);
+
 	Timer::Ptr m_RotationTimer;
-	void RotationTimerHandler(void);
-	void ScheduleNextRotation(void);
+	void RotationTimerHandler();
+	void ScheduleNextRotation();
 
 	std::ofstream m_OutputFile;
 	void ReopenFile(bool rotate);
