@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -31,7 +31,7 @@ namespace icinga
  *
  * @ingroup ido
  */
-class UserDbObject : public DbObject
+class UserDbObject final : public DbObject
 {
 public:
 	DECLARE_PTR_TYPEDEFS(UserDbObject);
@@ -39,12 +39,12 @@ public:
 	UserDbObject(const DbType::Ptr& type, const String& name1, const String& name2);
 
 protected:
-	virtual Dictionary::Ptr GetConfigFields(void) const override;
-	virtual Dictionary::Ptr GetStatusFields(void) const override;
+	Dictionary::Ptr GetConfigFields() const override;
+	Dictionary::Ptr GetStatusFields() const override;
 
-	virtual void OnConfigUpdateHeavy(void) override;
+	void OnConfigUpdateHeavy() override;
 
-	virtual String CalculateConfigHash(const Dictionary::Ptr& configFields) const override;
+	String CalculateConfigHash(const Dictionary::Ptr& configFields) const override;
 };
 
 }
