@@ -519,11 +519,12 @@ void IdoMysqlConnection::FinishAsyncQueries()
 
 			size_t size_query = aq.Query.GetLength() + 1;
 
-			if (num_bytes + size_query > m_MaxPacketSize - 512)
-				break;
+			if (count > 0) {
+				if (num_bytes + size_query > m_MaxPacketSize - 512)
+					break;
 
-			if (count > 0)
 				querybuf << ";";
+			}
 
 			IncreaseQueryCount();
 			count++;
@@ -830,8 +831,6 @@ bool IdoMysqlConnection::FieldToEscapedString(const String& key, const Value& va
 		std::ostringstream msgbuf;
 		msgbuf << "FROM_UNIXTIME(" << ts << ")";
 		*result = Value(msgbuf.str());
-	} else if (DbValue::IsTimestampNow(value)) {
-		*result = "NOW()";
 	} else if (DbValue::IsObjectInsertID(value)) {
 		auto id = static_cast<long>(rawvalue);
 
