@@ -26,13 +26,13 @@ using namespace icinga;
 REGISTER_TYPE(CheckResult);
 
 INITIALIZE_ONCE([]() {
-	ScriptGlobal::Set("ServiceOK", ServiceOK);
-	ScriptGlobal::Set("ServiceWarning", ServiceWarning);
-	ScriptGlobal::Set("ServiceCritical", ServiceCritical);
-	ScriptGlobal::Set("ServiceUnknown", ServiceUnknown);
+	ScriptGlobal::Set("Icinga.ServiceOK", ServiceOK, true);
+	ScriptGlobal::Set("Icinga.ServiceWarning", ServiceWarning, true);
+	ScriptGlobal::Set("Icinga.ServiceCritical", ServiceCritical, true);
+	ScriptGlobal::Set("Icinga.ServiceUnknown", ServiceUnknown, true);
 
-	ScriptGlobal::Set("HostUp", HostUp);
-	ScriptGlobal::Set("HostDown", HostDown);
+	ScriptGlobal::Set("Icinga.HostUp", HostUp, true);
+	ScriptGlobal::Set("Icinga.HostDown", HostDown, true);
 })
 
 double CheckResult::CalculateExecutionTime() const
