@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -18,7 +18,7 @@
  ******************************************************************************/
 
 #include "icinga/host.hpp"
-#include "icinga/host.tcpp"
+#include "icinga/host-ti.cpp"
 #include "icinga/service.hpp"
 #include "icinga/hostgroup.hpp"
 #include "icinga/pluginutility.hpp"
@@ -33,7 +33,7 @@ using namespace icinga;
 
 REGISTER_TYPE(Host);
 
-void Host::OnAllConfigLoaded(void)
+void Host::OnAllConfigLoaded()
 {
 	ObjectImpl<Host>::OnAllConfigLoaded();
 
@@ -99,7 +99,7 @@ void Host::Stop(bool runtimeRemoved)
 	// TODO: unregister slave services/notifications?
 }
 
-std::vector<Service::Ptr> Host::GetServices(void) const
+std::vector<Service::Ptr> Host::GetServices() const
 {
 	boost::mutex::scoped_lock lock(m_ServicesMutex);
 
@@ -127,7 +127,7 @@ void Host::RemoveService(const Service::Ptr& service)
 	m_Services.erase(service->GetShortName());
 }
 
-int Host::GetTotalServices(void) const
+int Host::GetTotalServices() const
 {
 	return GetServices().size();
 }
@@ -144,7 +144,7 @@ Service::Ptr Host::GetServiceByShortName(const Value& name)
 				return it->second;
 		}
 
-		return Service::Ptr();
+		return nullptr;
 	} else if (name.IsObjectType<Dictionary>()) {
 		Dictionary::Ptr dict = name;
 		String short_name;
@@ -166,23 +166,23 @@ HostState Host::CalculateState(ServiceState state)
 	}
 }
 
-HostState Host::GetState(void) const
+HostState Host::GetState() const
 {
 	return CalculateState(GetStateRaw());
 }
 
-HostState Host::GetLastState(void) const
+HostState Host::GetLastState() const
 {
 	return CalculateState(GetLastStateRaw());
 }
 
-HostState Host::GetLastHardState(void) const
+HostState Host::GetLastHardState() const
 {
 	return CalculateState(GetLastHardStateRaw());
 }
 
 /* keep in sync with Service::GetSeverity() */
-int Host::GetSeverity(void) const
+int Host::GetSeverity() const
 {
 	int severity = 0;
 
@@ -288,7 +288,7 @@ bool Host::ResolveMacro(const String& macro, const CheckResult::Ptr&, Value *res
 		*result = Utility::GetTime() - GetLastStateChange();
 		return true;
 	} else if (macro == "num_services" || macro == "num_services_ok" || macro == "num_services_warning"
-		    || macro == "num_services_unknown" || macro == "num_services_critical") {
+			|| macro == "num_services_unknown" || macro == "num_services_critical") {
 			int filter = -1;
 			int count = 0;
 
