@@ -46,12 +46,13 @@ public:
 
 	static IcingaApplication::Ptr GetInstance();
 
-	String GetPidPath() const;
-
 	bool ResolveMacro(const String& macro, const CheckResult::Ptr& cr, Value *result) const override;
 
 	String GetNodeName() const;
 
+	String GetEnvironment() const override;
+	void SetEnvironment(const String& value, bool suppress_events = false, const Value& cookie = Empty) override;
+
 	void ValidateVars(const Lazy<Dictionary::Ptr>& lvalue, const ValidationUtils& utils) override;
 
 private:
