@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -31,14 +31,14 @@ namespace icinga
 /**
  * @ingroup icinga
  */
-class I2_ICINGA_API ObjectUtils
+class ObjectUtils
 {
 public:
 	static Service::Ptr GetService(const Value& host, const String& name);
 	static Array::Ptr GetServices(const Value& host);
 
 private:
-	ObjectUtils(void);
+	ObjectUtils();
 };
 
 }
