@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -21,18 +21,15 @@
 
 using namespace icinga;
 
-Aggregator::Aggregator(void)
-{ }
-
 void Aggregator::SetFilter(const Filter::Ptr& filter)
 {
 	m_Filter = filter;
 }
 
-Filter::Ptr Aggregator::GetFilter(void) const
+Filter::Ptr Aggregator::GetFilter() const
 {
 	return m_Filter;
 }
 
-AggregatorState::~AggregatorState(void)
+AggregatorState::~AggregatorState()
 { }
