@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -29,28 +29,24 @@ namespace icinga
 /**
  * @ingroup livestatus
  */
-struct AvgAggregatorState : public AggregatorState
+struct AvgAggregatorState final : public AggregatorState
 {
-	AvgAggregatorState(void)
-	    : Avg(0), AvgCount(0)
-	{ }
-
-	double Avg;
-	double AvgCount;
+	double Avg{0};
+	double AvgCount{0};
 };
 
 /**
  * @ingroup livestatus
  */
-class I2_LIVESTATUS_API AvgAggregator : public Aggregator
+class AvgAggregator final : public Aggregator
 {
 public:
 	DECLARE_PTR_TYPEDEFS(AvgAggregator);
 
-	AvgAggregator(const String& attr);
+	AvgAggregator(String attr);
 
-	virtual void Apply(const Table::Ptr& table, const Value& row, AggregatorState **state) override;
-	virtual double GetResultAndFreeState(AggregatorState *state) const override;
+	void Apply(const Table::Ptr& table, const Value& row, AggregatorState **state) override;
+	double GetResultAndFreeState(AggregatorState *state) const override;
 
 private:
 	String m_AvgAttr;
