@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -21,8 +21,8 @@
 
 using namespace icinga;
 
-InvAvgAggregator::InvAvgAggregator(const String& attr)
-    : m_InvAvgAttr(attr)
+InvAvgAggregator::InvAvgAggregator(String attr)
+	: m_InvAvgAttr(std::move(attr))
 { }
 
 InvAvgAggregatorState *InvAvgAggregator::EnsureState(AggregatorState **state)
