@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -29,28 +29,24 @@ namespace icinga
 /**
  * @ingroup livestatus
  */
-struct InvAvgAggregatorState : public AggregatorState
+struct InvAvgAggregatorState final : public AggregatorState
 {
-	InvAvgAggregatorState(void)
-	    : InvAvg(0), InvAvgCount(0)
-	{ }
-
-	double InvAvg;
-	double InvAvgCount;
+	double InvAvg{0};
+	double InvAvgCount{0};
 };
 
 /**
  * @ingroup livestatus
  */
-class I2_LIVESTATUS_API InvAvgAggregator : public Aggregator
+class InvAvgAggregator final : public Aggregator
 {
 public:
 	DECLARE_PTR_TYPEDEFS(InvAvgAggregator);
 
-	InvAvgAggregator(const String& attr);
+	InvAvgAggregator(String attr);
 
-	virtual void Apply(const Table::Ptr& table, const Value& row, AggregatorState **state) override;
-	virtual double GetResultAndFreeState(AggregatorState *state) const override;
+	void Apply(const Table::Ptr& table, const Value& row, AggregatorState **state) override;
+	double GetResultAndFreeState(AggregatorState *state) const override;
 
 private:
 	String m_InvAvgAttr;
