@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -21,9 +21,6 @@
 
 using namespace icinga;
 
-OrFilter::OrFilter(void)
-{ }
-
 bool OrFilter::Apply(const Table::Ptr& table, const Value& row)
 {
 	if (m_Filters.empty())
