@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -22,8 +22,8 @@
 
 using namespace icinga;
 
-StdAggregator::StdAggregator(const String& attr)
-    : m_StdAttr(attr)
+StdAggregator::StdAggregator(String attr)
+	: m_StdAttr(std::move(attr))
 { }
 
 StdAggregatorState *StdAggregator::EnsureState(AggregatorState **state)
