@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -21,8 +21,8 @@
 
 using namespace icinga;
 
-SumAggregator::SumAggregator(const String& attr)
-    : m_SumAttr(attr)
+SumAggregator::SumAggregator(String attr)
+	: m_SumAttr(std::move(attr))
 { }
 
 SumAggregatorState *SumAggregator::EnsureState(AggregatorState **state)
