@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -29,27 +29,23 @@ namespace icinga
 /**
  * @ingroup livestatus
  */
-struct I2_LIVESTATUS_API SumAggregatorState : public AggregatorState
+struct SumAggregatorState final : public AggregatorState
 {
-	SumAggregatorState(void)
-	    : Sum(0)
-	{ }
-
-	double Sum;
+	double Sum{0};
 };
 
 /**
  * @ingroup livestatus
  */
-class I2_LIVESTATUS_API SumAggregator : public Aggregator
+class SumAggregator final : public Aggregator
 {
 public:
 	DECLARE_PTR_TYPEDEFS(SumAggregator);
 
-	SumAggregator(const String& attr);
+	SumAggregator(String attr);
 
-	virtual void Apply(const Table::Ptr& table, const Value& row, AggregatorState **state) override;
-	virtual double GetResultAndFreeState(AggregatorState *state) const override;
+	void Apply(const Table::Ptr& table, const Value& row, AggregatorState **state) override;
+	double GetResultAndFreeState(AggregatorState *state) const override;
 
 private:
 	String m_SumAttr;
