@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -23,13 +23,13 @@
 
 using namespace icinga;
 
-ZonesTable::ZonesTable(void)
+ZonesTable::ZonesTable()
 {
 	AddColumns(this);
 }
 
 void ZonesTable::AddColumns(Table *table, const String& prefix,
-    const Column::ObjectAccessor& objectAccessor)
+	const Column::ObjectAccessor& objectAccessor)
 {
 	table->AddColumn(prefix + "name", Column(&ZonesTable::NameAccessor, objectAccessor));
 	table->AddColumn(prefix + "parent", Column(&ZonesTable::ParentAccessor, objectAccessor));
@@ -37,12 +37,12 @@ void ZonesTable::AddColumns(Table *table, const String& prefix,
 	table->AddColumn(prefix + "global", Column(&ZonesTable::GlobalAccessor, objectAccessor));
 }
 
-String ZonesTable::GetName(void) const
+String ZonesTable::GetName() const
 {
 	return "zones";
 }
 
-String ZonesTable::GetPrefix(void) const
+String ZonesTable::GetPrefix() const
 {
 	return "zone";
 }
@@ -89,16 +89,13 @@ Value ZonesTable::EndpointsAccessor(const Value& row)
 
 	std::set<Endpoint::Ptr> endpoints = zone->GetEndpoints();
 
-	Array::Ptr endpoint_names = new Array();
+	ArrayData result;
 
-	for (const Endpoint::Ptr endpoint : endpoints) {
-		endpoint_names->Add(endpoint->GetName());
+	for (const Endpoint::Ptr& endpoint : endpoints) {
+		result.push_back(endpoint->GetName());
 	}
 
-	if (!endpoint_names)
-		return Empty;
-
-	return endpoint_names;
+	return new Array(std::move(result));
 }
 
 Value ZonesTable::GlobalAccessor(const Value& row)
