@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -18,7 +18,7 @@
  ******************************************************************************/
 
 #include "perfdata/graphitewriter.hpp"
-#include "perfdata/graphitewriter.tcpp"
+#include "perfdata/graphitewriter-ti.cpp"
 #include "icinga/service.hpp"
 #include "icinga/macroprocessor.hpp"
 #include "icinga/icingaapplication.hpp"
@@ -35,9 +35,8 @@
 #include "base/exception.hpp"
 #include "base/statsfunction.hpp"
 #include <boost/algorithm/string.hpp>
-#include <boost/algorithm/string/classification.hpp>
-#include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/replace.hpp>
+#include <utility>
 
 using namespace icinga;
 
@@ -45,11 +44,7 @@ REGISTER_TYPE(GraphiteWriter);
 
 REGISTER_STATSFUNCTION(GraphiteWriter, &GraphiteWriter::StatsFunc);
 
-GraphiteWriter::GraphiteWriter(void)
-    : m_WorkQueue(10000000, 1)
-{ }
-
-void GraphiteWriter::OnConfigLoaded(void)
+void GraphiteWriter::OnConfigLoaded()
 {
 	ObjectImpl<GraphiteWriter>::OnConfigLoaded();
 
@@ -58,24 +53,23 @@ void GraphiteWriter::OnConfigLoaded(void)
 
 void GraphiteWriter::StatsFunc(const Dictionary::Ptr& status, const Array::Ptr& perfdata)
 {
-	Dictionary::Ptr nodes = new Dictionary();
+	DictionaryData nodes;
 
 	for (const GraphiteWriter::Ptr& graphitewriter : ConfigType::GetObjectsByType<GraphiteWriter>()) {
 		size_t workQueueItems = graphitewriter->m_WorkQueue.GetLength();
 		double workQueueItemRate = graphitewriter->m_WorkQueue.GetTaskCount(60) / 60.0;
 
-		Dictionary::Ptr stats = new Dictionary();
-		stats->Set("work_queue_items", workQueueItems);
-		stats->Set("work_queue_item_rate", workQueueItemRate);
-		stats->Set("connected", graphitewriter->GetConnected());
-
-		nodes->Set(graphitewriter->GetName(), stats);
+		nodes.emplace_back(graphitewriter->GetName(), new Dictionary({
+			{ "work_queue_items", workQueueItems },
+			{ "work_queue_item_rate", workQueueItemRate },
+			{ "connected", graphitewriter->GetConnected() }
+		}));
 
 		perfdata->Add(new PerfdataValue("graphitewriter_" + graphitewriter->GetName() + "_work_queue_items", workQueueItems));
 		perfdata->Add(new PerfdataValue("graphitewriter_" + graphitewriter->GetName() + "_work_queue_item_rate", workQueueItemRate));
 	}
 
-	status->Set("graphitewriter", nodes);
+	status->Set("graphitewriter", new Dictionary(std::move(nodes)));
 }
 
 void GraphiteWriter::Start(bool runtimeCreated)
@@ -83,33 +77,33 @@ void GraphiteWriter::Start(bool runtimeCreated)
 	ObjectImpl<GraphiteWriter>::Start(runtimeCreated);
 
 	Log(LogInformation, "GraphiteWriter")
-	    << "'" << GetName() << "' started.";
+		<< "'" << GetName() << "' started.";
 
 	/* Register exception handler for WQ tasks. */
-	m_WorkQueue.SetExceptionCallback(boost::bind(&GraphiteWriter::ExceptionHandler, this, _1));
+	m_WorkQueue.SetExceptionCallback(std::bind(&GraphiteWriter::ExceptionHandler, this, _1));
 
 	/* Timer for reconnecting */
 	m_ReconnectTimer = new Timer();
 	m_ReconnectTimer->SetInterval(10);
-	m_ReconnectTimer->OnTimerExpired.connect(boost::bind(&GraphiteWriter::ReconnectTimerHandler, this));
+	m_ReconnectTimer->OnTimerExpired.connect(std::bind(&GraphiteWriter::ReconnectTimerHandler, this));
 	m_ReconnectTimer->Start();
 	m_ReconnectTimer->Reschedule(0);
 
 	/* Register event handlers. */
-	Checkable::OnNewCheckResult.connect(boost::bind(&GraphiteWriter::CheckResultHandler, this, _1, _2));
+	Checkable::OnNewCheckResult.connect(std::bind(&GraphiteWriter::CheckResultHandler, this, _1, _2));
 }
 
 void GraphiteWriter::Stop(bool runtimeRemoved)
 {
 	Log(LogInformation, "GraphiteWriter")
-	    << "'" << GetName() << "' stopped.";
+		<< "'" << GetName() << "' stopped.";
 
 	m_WorkQueue.Join();
 
 	ObjectImpl<GraphiteWriter>::Stop(runtimeRemoved);
 }
 
-void GraphiteWriter::AssertOnWorkQueue(void)
+void GraphiteWriter::AssertOnWorkQueue()
 {
 	ASSERT(m_WorkQueue.IsWorkerThread());
 }
@@ -119,7 +113,7 @@ void GraphiteWriter::ExceptionHandler(boost::exception_ptr exp)
 	Log(LogCritical, "GraphiteWriter", "Exception during Graphite operation: Verify that your backend is operational!");
 
 	Log(LogDebug, "GraphiteWriter")
-	    << "Exception during Graphite operation: " << DiagnosticInformation(exp);
+		<< "Exception during Graphite operation: " << DiagnosticInformation(std::move(exp));
 
 	if (GetConnected()) {
 		m_Stream->Close();
@@ -128,7 +122,7 @@ void GraphiteWriter::ExceptionHandler(boost::exception_ptr exp)
 	}
 }
 
-void GraphiteWriter::Reconnect(void)
+void GraphiteWriter::Reconnect()
 {
 	AssertOnWorkQueue();
 
@@ -144,13 +138,13 @@ void GraphiteWriter::Reconnect(void)
 	TcpSocket::Ptr socket = new TcpSocket();
 
 	Log(LogNotice, "GraphiteWriter")
-	    << "Reconnecting to Graphite on host '" << GetHost() << "' port '" << GetPort() << "'.";
+		<< "Reconnecting to Graphite on host '" << GetHost() << "' port '" << GetPort() << "'.";
 
 	try {
 		socket->Connect(GetHost(), GetPort());
 	} catch (const std::exception& ex) {
 		Log(LogCritical, "GraphiteWriter")
-		    << "Can't connect to Graphite on host '" << GetHost() << "' port '" << GetPort() << "'.";
+			<< "Can't connect to Graphite on host '" << GetHost() << "' port '" << GetPort() << "'.";
 		throw ex;
 	}
 
@@ -159,15 +153,15 @@ void GraphiteWriter::Reconnect(void)
 	SetConnected(true);
 
 	Log(LogInformation, "GraphiteWriter")
-	    << "Finished reconnecting to Graphite in " << std::setw(2) << Utility::GetTime() - startTime << " second(s).";
+		<< "Finished reconnecting to Graphite in " << std::setw(2) << Utility::GetTime() - startTime << " second(s).";
 }
 
-void GraphiteWriter::ReconnectTimerHandler(void)
+void GraphiteWriter::ReconnectTimerHandler()
 {
-	m_WorkQueue.Enqueue(boost::bind(&GraphiteWriter::Reconnect, this), PriorityNormal);
+	m_WorkQueue.Enqueue(std::bind(&GraphiteWriter::Reconnect, this), PriorityNormal);
 }
 
-void GraphiteWriter::Disconnect(void)
+void GraphiteWriter::Disconnect()
 {
 	AssertOnWorkQueue();
 
@@ -181,7 +175,7 @@ void GraphiteWriter::Disconnect(void)
 
 void GraphiteWriter::CheckResultHandler(const Checkable::Ptr& checkable, const CheckResult::Ptr& cr)
 {
-	m_WorkQueue.Enqueue(boost::bind(&GraphiteWriter::CheckResultHandlerInternal, this, checkable, cr));
+	m_WorkQueue.Enqueue(std::bind(&GraphiteWriter::CheckResultHandlerInternal, this, checkable, cr));
 }
 
 void GraphiteWriter::CheckResultHandlerInternal(const Checkable::Ptr& checkable, const CheckResult::Ptr& cr)
@@ -195,20 +189,20 @@ void GraphiteWriter::CheckResultHandlerInternal(const Checkable::Ptr& checkable,
 
 	Host::Ptr host;
 	Service::Ptr service;
-	boost::tie(host, service) = GetHostService(checkable);
+	tie(host, service) = GetHostService(checkable);
 
 	MacroProcessor::ResolverList resolvers;
 	if (service)
-		resolvers.push_back(std::make_pair("service", service));
-	resolvers.push_back(std::make_pair("host", host));
-	resolvers.push_back(std::make_pair("icinga", IcingaApplication::GetInstance()));
+		resolvers.emplace_back("service", service);
+	resolvers.emplace_back("host", host);
+	resolvers.emplace_back("icinga", IcingaApplication::GetInstance());
 
 	String prefix;
 
 	if (service) {
-		prefix = MacroProcessor::ResolveMacros(GetServiceNameTemplate(), resolvers, cr, NULL, boost::bind(&GraphiteWriter::EscapeMacroMetric, _1));
+		prefix = MacroProcessor::ResolveMacros(GetServiceNameTemplate(), resolvers, cr, nullptr, std::bind(&GraphiteWriter::EscapeMacroMetric, _1));
 	} else {
-		prefix = MacroProcessor::ResolveMacros(GetHostNameTemplate(), resolvers, cr, NULL, boost::bind(&GraphiteWriter::EscapeMacroMetric, _1));
+		prefix = MacroProcessor::ResolveMacros(GetHostNameTemplate(), resolvers, cr, nullptr, std::bind(&GraphiteWriter::EscapeMacroMetric, _1));
 	}
 
 	String prefixPerfdata = prefix + ".perfdata";
@@ -254,7 +248,7 @@ void GraphiteWriter::SendPerfdata(const String& prefix, const CheckResult::Ptr&
 				pdv = PerfdataValue::Parse(val);
 			} catch (const std::exception&) {
 				Log(LogWarning, "GraphiteWriter")
-				    << "Ignoring invalid perfdata value: " << val;
+					<< "Ignoring invalid perfdata value: " << val;
 				continue;
 			}
 		}
@@ -282,7 +276,7 @@ void GraphiteWriter::SendMetric(const String& prefix, const String& name, double
 	msgbuf << prefix << "." << name << " " << Convert::ToString(value) << " " << static_cast<long>(ts);
 
 	Log(LogDebug, "GraphiteWriter")
-	    << "Add to metric list:'" << msgbuf.str() << "'.";
+		<< "Add to metric list:'" << msgbuf.str() << "'.";
 
 	// do not send \n to debug log
 	msgbuf << "\n";
@@ -297,7 +291,7 @@ void GraphiteWriter::SendMetric(const String& prefix, const String& name, double
 		m_Stream->Write(metric.CStr(), metric.GetLength());
 	} catch (const std::exception& ex) {
 		Log(LogCritical, "GraphiteWriter")
-		    << "Cannot write to TCP socket on host '" << GetHost() << "' port '" << GetPort() << "'.";
+			<< "Cannot write to TCP socket on host '" << GetHost() << "' port '" << GetPort() << "'.";
 
 		throw ex;
 	}
@@ -333,30 +327,30 @@ Value GraphiteWriter::EscapeMacroMetric(const Value& value)
 {
 	if (value.IsObjectType<Array>()) {
 		Array::Ptr arr = value;
-		Array::Ptr result = new Array();
+		ArrayData result;
 
 		ObjectLock olock(arr);
 		for (const Value& arg : arr) {
-			result->Add(EscapeMetric(arg));
+			result.push_back(EscapeMetric(arg));
 		}
 
-		return Utility::Join(result, '.');
+		return Utility::Join(new Array(std::move(result)), '.');
 	} else
 		return EscapeMetric(value);
 }
 
-void GraphiteWriter::ValidateHostNameTemplate(const String& value, const ValidationUtils& utils)
+void GraphiteWriter::ValidateHostNameTemplate(const Lazy<String>& lvalue, const ValidationUtils& utils)
 {
-	ObjectImpl<GraphiteWriter>::ValidateHostNameTemplate(value, utils);
+	ObjectImpl<GraphiteWriter>::ValidateHostNameTemplate(lvalue, utils);
 
-	if (!MacroProcessor::ValidateMacroString(value))
-		BOOST_THROW_EXCEPTION(ValidationError(this, boost::assign::list_of("host_name_template"), "Closing $ not found in macro format string '" + value + "'."));
+	if (!MacroProcessor::ValidateMacroString(lvalue()))
+		BOOST_THROW_EXCEPTION(ValidationError(this, { "host_name_template" }, "Closing $ not found in macro format string '" + lvalue() + "'."));
 }
 
-void GraphiteWriter::ValidateServiceNameTemplate(const String& value, const ValidationUtils& utils)
+void GraphiteWriter::ValidateServiceNameTemplate(const Lazy<String>& lvalue, const ValidationUtils& utils)
 {
-	ObjectImpl<GraphiteWriter>::ValidateServiceNameTemplate(value, utils);
+	ObjectImpl<GraphiteWriter>::ValidateServiceNameTemplate(lvalue, utils);
 
-	if (!MacroProcessor::ValidateMacroString(value))
-		BOOST_THROW_EXCEPTION(ValidationError(this, boost::assign::list_of("service_name_template"), "Closing $ not found in macro format string '" + value + "'."));
+	if (!MacroProcessor::ValidateMacroString(lvalue()))
+		BOOST_THROW_EXCEPTION(ValidationError(this, { "service_name_template" }, "Closing $ not found in macro format string '" + lvalue() + "'."));
 }
