@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -20,7 +20,7 @@
 #ifndef GRAPHITEWRITER_H
 #define GRAPHITEWRITER_H
 
-#include "perfdata/graphitewriter.thpp"
+#include "perfdata/graphitewriter-ti.hpp"
 #include "icinga/service.hpp"
 #include "base/configobject.hpp"
 #include "base/tcpsocket.hpp"
@@ -36,27 +36,25 @@ namespace icinga
  *
  * @ingroup perfdata
  */
-class GraphiteWriter : public ObjectImpl<GraphiteWriter>
+class GraphiteWriter final : public ObjectImpl<GraphiteWriter>
 {
 public:
 	DECLARE_OBJECT(GraphiteWriter);
 	DECLARE_OBJECTNAME(GraphiteWriter);
 
-	GraphiteWriter(void);
-
 	static void StatsFunc(const Dictionary::Ptr& status, const Array::Ptr& perfdata);
 
-	virtual void ValidateHostNameTemplate(const String& value, const ValidationUtils& utils) override;
-	virtual void ValidateServiceNameTemplate(const String& value, const ValidationUtils& utils) override;
+	void ValidateHostNameTemplate(const Lazy<String>& lvalue, const ValidationUtils& utils) override;
+	void ValidateServiceNameTemplate(const Lazy<String>& lvalue, const ValidationUtils& utils) override;
 
 protected:
-	virtual void OnConfigLoaded(void) override;
-	virtual void Start(bool runtimeCreated) override;
-	virtual void Stop(bool runtimeRemoved) override;
+	void OnConfigLoaded() override;
+	void Start(bool runtimeCreated) override;
+	void Stop(bool runtimeRemoved) override;
 
 private:
 	Stream::Ptr m_Stream;
-	WorkQueue m_WorkQueue;
+	WorkQueue m_WorkQueue{10000000, 1};
 
 	Timer::Ptr m_ReconnectTimer;
 
@@ -68,12 +66,12 @@ private:
 	static String EscapeMetricLabel(const String& str);
 	static Value EscapeMacroMetric(const Value& value);
 
-	void ReconnectTimerHandler(void);
+	void ReconnectTimerHandler();
 
-	void Disconnect(void);
-	void Reconnect(void);
+	void Disconnect();
+	void Reconnect();
 
-	void AssertOnWorkQueue(void);
+	void AssertOnWorkQueue();
 
 	void ExceptionHandler(boost::exception_ptr exp);
 };
