@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -22,7 +22,6 @@
 #include "remote/httputility.hpp"
 #include "remote/filterutility.hpp"
 #include "base/exception.hpp"
-#include <boost/algorithm/string/join.hpp>
 
 using namespace icinga;
 
@@ -34,7 +33,7 @@ bool ConfigPackagesHandler::HandleRequest(const ApiUser::Ptr& user, HttpRequest&
 		return false;
 
 	if (request.RequestMethod == "GET")
-		HandleGet(user, request, response);
+		HandleGet(user, request, response, params);
 	else if (request.RequestMethod == "POST")
 		HandlePost(user, request, response, params);
 	else if (request.RequestMethod == "DELETE")
@@ -45,7 +44,7 @@ bool ConfigPackagesHandler::HandleRequest(const ApiUser::Ptr& user, HttpRequest&
 	return true;
 }
 
-void ConfigPackagesHandler::HandleGet(const ApiUser::Ptr& user, HttpRequest& request, HttpResponse& response)
+void ConfigPackagesHandler::HandleGet(const ApiUser::Ptr& user, HttpRequest& request, HttpResponse& response, const Dictionary::Ptr& params)
 {
 	FilterUtility::CheckPermission(user, "config/query");
 
@@ -54,28 +53,30 @@ void ConfigPackagesHandler::HandleGet(const ApiUser::Ptr& user, HttpRequest& req
 	try {
 		packages = ConfigPackageUtility::GetPackages();
 	} catch (const std::exception& ex) {
-		HttpUtility::SendJsonError(response, 500, "Could not retrieve packages.");
+		HttpUtility::SendJsonError(response, params, 500, "Could not retrieve packages.",
+			DiagnosticInformation(ex));
 		return;
 	}
 
-	Array::Ptr results = new Array();
+	ArrayData results;
 
 	{
 		boost::mutex::scoped_lock lock(ConfigPackageUtility::GetStaticMutex());
 		for (const String& package : packages) {
-			Dictionary::Ptr packageInfo = new Dictionary();
-			packageInfo->Set("name", package);
-			packageInfo->Set("stages", Array::FromVector(ConfigPackageUtility::GetStages(package)));
-			packageInfo->Set("active-stage", ConfigPackageUtility::GetActiveStage(package));
-			results->Add(packageInfo);
+			results.emplace_back(new Dictionary({
+				{ "name", package },
+				{ "stages", Array::FromVector(ConfigPackageUtility::GetStages(package)) },
+				{ "active-stage", ConfigPackageUtility::GetActiveStage(package) }
+			}));
 		}
 	}
 
-	Dictionary::Ptr result = new Dictionary();
-	result->Set("results", results);
+	Dictionary::Ptr result = new Dictionary({
+		{ "results", new Array(std::move(results)) }
+	});
 
 	response.SetStatus(200, "OK");
-	HttpUtility::SendJsonBody(response, result);
+	HttpUtility::SendJsonBody(response, params, result);
 }
 
 void ConfigPackagesHandler::HandlePost(const ApiUser::Ptr& user, HttpRequest& request, HttpResponse& response, const Dictionary::Ptr& params)
@@ -88,32 +89,31 @@ void ConfigPackagesHandler::HandlePost(const ApiUser::Ptr& user, HttpRequest& re
 	String packageName = HttpUtility::GetLastParameter(params, "package");
 
 	if (!ConfigPackageUtility::ValidateName(packageName)) {
-		HttpUtility::SendJsonError(response, 400, "Invalid package name.");
+		HttpUtility::SendJsonError(response, params, 400, "Invalid package name '" + packageName + "'.");
 		return;
 	}
 
-	Dictionary::Ptr result1 = new Dictionary();
-
 	try {
 		boost::mutex::scoped_lock lock(ConfigPackageUtility::GetStaticMutex());
 		ConfigPackageUtility::CreatePackage(packageName);
 	} catch (const std::exception& ex) {
-		HttpUtility::SendJsonError(response, 500, "Could not create package.",
-			HttpUtility::GetLastParameter(params, "verboseErrors") ? DiagnosticInformation(ex) : "");
+		HttpUtility::SendJsonError(response, params, 500, "Could not create package '" + packageName + "'.",
+			DiagnosticInformation(ex));
 		return;
 	}
 
-	result1->Set("code", 200);
-	result1->Set("status", "Created package.");
+	Dictionary::Ptr result1 = new Dictionary({
+		{ "code", 200 },
+		{ "package", packageName },
+		{ "status", "Created package." }
+	});
 
-	Array::Ptr results = new Array();
-	results->Add(result1);
-
-	Dictionary::Ptr result = new Dictionary();
-	result->Set("results", results);
+	Dictionary::Ptr result = new Dictionary({
+		{ "results", new Array({ result1 }) }
+	});
 
 	response.SetStatus(200, "OK");
-	HttpUtility::SendJsonBody(response, result);
+	HttpUtility::SendJsonBody(response, params, result);
 }
 
 void ConfigPackagesHandler::HandleDelete(const ApiUser::Ptr& user, HttpRequest& request, HttpResponse& response, const Dictionary::Ptr& params)
@@ -126,35 +126,28 @@ void ConfigPackagesHandler::HandleDelete(const ApiUser::Ptr& user, HttpRequest&
 	String packageName = HttpUtility::GetLastParameter(params, "package");
 
 	if (!ConfigPackageUtility::ValidateName(packageName)) {
-		HttpUtility::SendJsonError(response, 400, "Invalid package name.");
+		HttpUtility::SendJsonError(response, params, 400, "Invalid package name '" + packageName + "'.");
 		return;
 	}
 
-	int code = 200;
-	String status = "Deleted package.";
-	Dictionary::Ptr result1 = new Dictionary();
-
 	try {
 		ConfigPackageUtility::DeletePackage(packageName);
 	} catch (const std::exception& ex) {
-		code = 500;
-		status = "Failed to delete package.";
-		if (HttpUtility::GetLastParameter(params, "verboseErrors"))
-			result1->Set("diagnostic information", DiagnosticInformation(ex));
+		HttpUtility::SendJsonError(response, params, 500, "Failed to delete package '" + packageName + "'.",
+			DiagnosticInformation(ex));
+		return;
 	}
 
+	Dictionary::Ptr result1 = new Dictionary({
+		{ "code", 200 },
+		{ "package", packageName },
+		{ "status", "Deleted package." }
+	});
 
-	result1->Set("package", packageName);
-	result1->Set("code", code);
-	result1->Set("status", status);
+	Dictionary::Ptr result = new Dictionary({
+		{ "results", new Array({ result1 }) }
+	});
 
-	Array::Ptr results = new Array();
-	results->Add(result1);
-
-	Dictionary::Ptr result = new Dictionary();
-	result->Set("results", results);
-
-	response.SetStatus(code, (code == 200) ? "OK" : "Internal Server Error");
-	HttpUtility::SendJsonBody(response, result);
+	response.SetStatus(200, "OK");
+	HttpUtility::SendJsonBody(response, params, result);
 }
-
