@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -18,7 +18,7 @@
  ******************************************************************************/
 
 #include "remote/endpoint.hpp"
-#include "remote/endpoint.tcpp"
+#include "remote/endpoint-ti.cpp"
 #include "remote/apilistener.hpp"
 #include "remote/jsonrpcconnection.hpp"
 #include "remote/zone.hpp"
@@ -34,20 +34,20 @@ REGISTER_TYPE(Endpoint);
 boost::signals2::signal<void(const Endpoint::Ptr&, const JsonRpcConnection::Ptr&)> Endpoint::OnConnected;
 boost::signals2::signal<void(const Endpoint::Ptr&, const JsonRpcConnection::Ptr&)> Endpoint::OnDisconnected;
 
-void Endpoint::OnAllConfigLoaded(void)
+void Endpoint::OnAllConfigLoaded()
 {
 	ObjectImpl<Endpoint>::OnAllConfigLoaded();
 
 	if (!m_Zone)
 		BOOST_THROW_EXCEPTION(ScriptError("Endpoint '" + GetName() +
-		    "' does not belong to a zone.", GetDebugInfo()));
+			"' does not belong to a zone.", GetDebugInfo()));
 }
 
 void Endpoint::SetCachedZone(const Zone::Ptr& zone)
 {
 	if (m_Zone)
 		BOOST_THROW_EXCEPTION(ScriptError("Endpoint '" + GetName()
-		    + "' is in more than one zone.", GetDebugInfo()));
+			+ "' is in more than one zone.", GetDebugInfo()));
 
 	m_Zone = zone;
 }
@@ -78,7 +78,7 @@ void Endpoint::RemoveClient(const JsonRpcConnection::Ptr& client)
 		m_Clients.erase(client);
 
 		Log(LogWarning, "ApiListener")
-		    << "Removing API client for endpoint '" << GetName() << "'. " << m_Clients.size() << " API clients left.";
+			<< "Removing API client for endpoint '" << GetName() << "'. " << m_Clients.size() << " API clients left.";
 
 		SetConnecting(false);
 	}
@@ -91,29 +91,65 @@ void Endpoint::RemoveClient(const JsonRpcConnection::Ptr& client)
 	OnDisconnected(this, client);
 }
 
-std::set<JsonRpcConnection::Ptr> Endpoint::GetClients(void) const
+std::set<JsonRpcConnection::Ptr> Endpoint::GetClients() const
 {
 	boost::mutex::scoped_lock lock(m_ClientsLock);
 	return m_Clients;
 }
 
-Zone::Ptr Endpoint::GetZone(void) const
+Zone::Ptr Endpoint::GetZone() const
 {
 	return m_Zone;
 }
 
-bool Endpoint::GetConnected(void) const
+bool Endpoint::GetConnected() const
 {
 	boost::mutex::scoped_lock lock(m_ClientsLock);
 	return !m_Clients.empty();
 }
 
-Endpoint::Ptr Endpoint::GetLocalEndpoint(void)
+Endpoint::Ptr Endpoint::GetLocalEndpoint()
 {
 	ApiListener::Ptr listener = ApiListener::GetInstance();
 
 	if (!listener)
-		return Endpoint::Ptr();
+		return nullptr;
 
 	return listener->GetLocalEndpoint();
 }
+
+void Endpoint::AddMessageSent(int bytes)
+{
+	double time = Utility::GetTime();
+	m_MessagesSent.InsertValue(time, 1);
+	m_BytesSent.InsertValue(time, bytes);
+	SetLastMessageSent(time);
+}
+
+void Endpoint::AddMessageReceived(int bytes)
+{
+	double time = Utility::GetTime();
+	m_MessagesReceived.InsertValue(time, 1);
+	m_BytesReceived.InsertValue(time, bytes);
+	SetLastMessageReceived(time);
+}
+
+double Endpoint::GetMessagesSentPerSecond() const
+{
+	return m_MessagesSent.CalculateRate(Utility::GetTime(), 60);
+}
+
+double Endpoint::GetMessagesReceivedPerSecond() const
+{
+	return m_MessagesReceived.CalculateRate(Utility::GetTime(), 60);
+}
+
+double Endpoint::GetBytesSentPerSecond() const
+{
+	return m_BytesSent.CalculateRate(Utility::GetTime(), 60);
+}
+
+double Endpoint::GetBytesReceivedPerSecond() const
+{
+	return m_BytesReceived.CalculateRate(Utility::GetTime(), 60);
+}
