@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -23,7 +23,6 @@
 #include "remote/httphandler.hpp"
 #include "base/object.hpp"
 #include "config/expression.hpp"
-#include <boost/thread/thread.hpp>
 #include <boost/thread/mutex.hpp>
 #include <boost/thread/condition_variable.hpp>
 #include <set>
@@ -33,13 +32,12 @@
 namespace icinga
 {
 
-class I2_REMOTE_API EventQueue : public Object
+class EventQueue final : public Object
 {
 public:
 	DECLARE_PTR_TYPEDEFS(EventQueue);
 
-	EventQueue(const String& name);
-	~EventQueue(void);
+	EventQueue(String name);
 
 	bool CanProcessEvent(const String& type) const;
 	void ProcessEvent(const Dictionary::Ptr& event);
@@ -47,7 +45,7 @@ public:
 	void RemoveClient(void *client);
 
 	void SetTypes(const std::set<String>& types);
-	void SetFilter(Expression *filter);
+	void SetFilter(std::unique_ptr<Expression> filter);
 
 	Dictionary::Ptr WaitForEvent(void *client, double timeout = 5);
 
@@ -65,7 +63,7 @@ private:
 	boost::condition_variable m_CV;
 
 	std::set<String> m_Types;
-	Expression *m_Filter;
+	std::unique_ptr<Expression> m_Filter;
 
 	std::map<void *, std::deque<Dictionary::Ptr> > m_Events;
 };
@@ -75,10 +73,10 @@ private:
  *
  * @ingroup base
  */
-class I2_REMOTE_API EventQueueRegistry : public Registry<EventQueueRegistry, EventQueue::Ptr>
+class EventQueueRegistry : public Registry<EventQueueRegistry, EventQueue::Ptr>
 {
 public:
-	static EventQueueRegistry *GetInstance(void);
+	static EventQueueRegistry *GetInstance();
 };
 
 }
