@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -39,14 +39,14 @@ bool EventsHandler::HandleRequest(const ApiUser::Ptr& user, HttpRequest& request
 		return false;
 
 	if (request.ProtocolVersion == HttpVersion10) {
-		HttpUtility::SendJsonError(response, 400, "HTTP/1.0 not supported for event streams.");
+		HttpUtility::SendJsonError(response, params, 400, "HTTP/1.0 not supported for event streams.");
 		return true;
 	}
 
 	Array::Ptr types = params->Get("types");
 
 	if (!types) {
-		HttpUtility::SendJsonError(response, 400, "'types' query parameter is required.");
+		HttpUtility::SendJsonError(response, params, 400, "'types' query parameter is required.");
 		return true;
 	}
 
@@ -60,13 +60,13 @@ bool EventsHandler::HandleRequest(const ApiUser::Ptr& user, HttpRequest& request
 	String queueName = HttpUtility::GetLastParameter(params, "queue");
 
 	if (queueName.IsEmpty()) {
-		HttpUtility::SendJsonError(response, 400, "'queue' query parameter is required.");
+		HttpUtility::SendJsonError(response, params, 400, "'queue' query parameter is required.");
 		return true;
 	}
 
 	String filter = HttpUtility::GetLastParameter(params, "filter");
 
-	Expression *ufilter = NULL;
+	std::unique_ptr<Expression> ufilter;
 
 	if (!filter.IsEmpty())
 		ufilter = ConfigCompiler::CompileText("<API query>", filter);
@@ -80,7 +80,7 @@ bool EventsHandler::HandleRequest(const ApiUser::Ptr& user, HttpRequest& request
 	}
 
 	queue->SetTypes(types->ToSet<String>());
-	queue->SetFilter(ufilter);
+	queue->SetFilter(std::move(ufilter));
 
 	queue->AddClient(&request);
 
