@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -49,7 +49,7 @@ enum HttpRequestState
  *
  * @ingroup remote
  */
-struct I2_REMOTE_API HttpRequest
+struct HttpRequest
 {
 public:
 	bool CompleteHeaders;
@@ -62,7 +62,7 @@ public:
 
 	Dictionary::Ptr Headers;
 
-	HttpRequest(const Stream::Ptr& stream);
+	HttpRequest(Stream::Ptr stream);
 
 	bool ParseHeaders(StreamReadContext& src, bool may_wait);
 	bool ParseBody(StreamReadContext& src, bool may_wait);
@@ -70,15 +70,15 @@ public:
 
 	void AddHeader(const String& key, const String& value);
 	void WriteBody(const char *data, size_t count);
-	void Finish(void);
+	void Finish();
 
 private:
 	Stream::Ptr m_Stream;
-	boost::shared_ptr<ChunkReadContext> m_ChunkContext;
+	std::shared_ptr<ChunkReadContext> m_ChunkContext;
 	HttpRequestState m_State;
 	FIFO::Ptr m_Body;
 
-	void FinishHeaders(void);
+	void FinishHeaders();
 };
 
 }
