@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -28,10 +28,4 @@
 
 #include "base/i2-base.hpp"
 
-#ifdef I2_REMOTE_BUILD
-#	define I2_REMOTE_API I2_EXPORT
-#else /* I2_REMOTE_BUILD */
-#	define I2_REMOTE_API I2_IMPORT
-#endif /* I2_REMOTE_BUILD */
-
 #endif /* I2REMOTE_H */
