@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -42,7 +42,7 @@ Value RequestCertificateHandler(const MessageOrigin::Ptr& origin, const Dictiona
 {
 	String certText = params->Get("cert_request");
 
-	boost::shared_ptr<X509> cert;
+	std::shared_ptr<X509> cert;
 
 	Dictionary::Ptr result = new Dictionary();
 
@@ -53,15 +53,15 @@ Value RequestCertificateHandler(const MessageOrigin::Ptr& origin, const Dictiona
 		cert = StringToCertificate(certText);
 
 	ApiListener::Ptr listener = ApiListener::GetInstance();
-	boost::shared_ptr<X509> cacert = GetX509Certificate(listener->GetDefaultCaPath());
+	std::shared_ptr<X509> cacert = GetX509Certificate(listener->GetDefaultCaPath());
 
 	String cn = GetCertificateCN(cert);
 
 	bool signedByCA = VerifyCertificate(cacert, cert);
 
 	Log(LogInformation, "JsonRpcConnection")
-	    << "Received certificate request for CN '" << cn << "'"
-	    << (signedByCA ? "" : " not") << " signed by our CA.";
+		<< "Received certificate request for CN '" << cn << "'"
+		<< (signedByCA ? "" : " not") << " signed by our CA.";
 
 	if (signedByCA) {
 		time_t now;
@@ -76,9 +76,9 @@ Value RequestCertificateHandler(const MessageOrigin::Ptr& origin, const Dictiona
 		if (X509_cmp_time(X509_get_notBefore(cert.get()), &forceRenewalEnd) != -1 && X509_cmp_time(X509_get_notAfter(cert.get()), &renewalStart) != -1) {
 
 			Log(LogInformation, "JsonRpcConnection")
-			    << "The certificate for CN '" << cn << "' cannot be renewed yet.";
+				<< "The certificate for CN '" << cn << "' is valid and uptodate. Skipping automated renewal.";
 			result->Set("status_code", 1);
-			result->Set("error", "The certificate for CN '" + cn + "' cannot be renewed yet.");
+			result->Set("error", "The certificate for CN '" + cn + "' is valid and uptodate. Skipping automated renewal.");
 			return result;
 		}
 	}
@@ -91,8 +91,8 @@ Value RequestCertificateHandler(const MessageOrigin::Ptr& origin, const Dictiona
 		result->Set("error", "Could not calculate fingerprint for the X509 certificate for CN '" + cn + "'.");
 
 		Log(LogWarning, "JsonRpcConnection")
-		    << "Could not calculate fingerprint for the X509 certificate requested for CN '"
-		    << cn << "'.";
+			<< "Could not calculate fingerprint for the X509 certificate requested for CN '"
+			<< cn << "'.";
 
 		return result;
 	}
@@ -118,24 +118,25 @@ Value RequestCertificateHandler(const MessageOrigin::Ptr& origin, const Dictiona
 
 		if (!certResponse.IsEmpty()) {
 			Log(LogInformation, "JsonRpcConnection")
-			    << "Sending certificate response for CN '" << cn
-			    << "' to endpoint '" << client->GetIdentity() << "'.";
+				<< "Sending certificate response for CN '" << cn
+				<< "' to endpoint '" << client->GetIdentity() << "'.";
 
 			result->Set("cert", certResponse);
 			result->Set("status_code", 0);
 
-			Dictionary::Ptr message = new Dictionary();
-			message->Set("jsonrpc", "2.0");
-			message->Set("method", "pki::UpdateCertificate");
-			message->Set("params", result);
+			Dictionary::Ptr message = new Dictionary({
+				{ "jsonrpc", "2.0" },
+				{ "method", "pki::UpdateCertificate" },
+				{ "params", result }
+			});
 			JsonRpc::SendMessage(client->GetStream(), message);
 
 			return result;
 		}
 	}
 
-	boost::shared_ptr<X509> newcert;
-	boost::shared_ptr<EVP_PKEY> pubkey;
+	std::shared_ptr<X509> newcert;
+	std::shared_ptr<EVP_PKEY> pubkey;
 	X509_NAME *subject;
 	Dictionary::Ptr message;
 	String ticket;
@@ -161,7 +162,7 @@ Value RequestCertificateHandler(const MessageOrigin::Ptr& origin, const Dictiona
 
 		if (ticket != realTicket) {
 			Log(LogWarning, "JsonRpcConnection")
-			    << "Ticket for CN '" << cn << "' is invalid.";
+				<< "Ticket '" << ticket << "' for CN '" << cn << "' is invalid.";
 
 			result->Set("status_code", 1);
 			result->Set("error", "Invalid ticket for CN '" + cn + "'.");
@@ -169,7 +170,7 @@ Value RequestCertificateHandler(const MessageOrigin::Ptr& origin, const Dictiona
 		}
 	}
 
-	pubkey = boost::shared_ptr<EVP_PKEY>(X509_get_pubkey(cert.get()), EVP_PKEY_free);
+	pubkey = std::shared_ptr<EVP_PKEY>(X509_get_pubkey(cert.get()), EVP_PKEY_free);
 	subject = X509_get_subject_name(cert.get());
 
 	newcert = CreateCertIcingaCA(pubkey.get(), subject);
@@ -180,24 +181,25 @@ Value RequestCertificateHandler(const MessageOrigin::Ptr& origin, const Dictiona
 	 * a certificate it wouldn't be able to use to connect to us anyway) */
 	if (!VerifyCertificate(cacert, newcert)) {
 		Log(LogWarning, "JsonRpcConnection")
-		    << "The CA in '" << listener->GetDefaultCaPath() << "' does not match the CA which Icinga uses "
-		    << "for its own cluster connections. This is most likely a configuration problem.";
+			<< "The CA in '" << listener->GetDefaultCaPath() << "' does not match the CA which Icinga uses "
+			<< "for its own cluster connections. This is most likely a configuration problem.";
 		goto delayed_request;
 	}
 
 	/* Send the signed certificate update. */
 	Log(LogInformation, "JsonRpcConnection")
-	    << "Sending certificate response for CN '" << cn << "' to endpoint '"
-	    << client->GetIdentity() << "'" << (!ticket.IsEmpty() ? " (auto-signing ticket)" : "" ) << ".";
+		<< "Sending certificate response for CN '" << cn << "' to endpoint '"
+		<< client->GetIdentity() << "'" << (!ticket.IsEmpty() ? " (auto-signing ticket)" : "" ) << ".";
 
 	result->Set("cert", CertificateToString(newcert));
 
 	result->Set("status_code", 0);
 
-	message = new Dictionary();
-	message->Set("jsonrpc", "2.0");
-	message->Set("method", "pki::UpdateCertificate");
-	message->Set("params", result);
+	message = new Dictionary({
+		{ "jsonrpc", "2.0" },
+		{ "method", "pki::UpdateCertificate" },
+		{ "params", result }
+	});
 	JsonRpc::SendMessage(client->GetStream(), message);
 
 	return result;
@@ -206,19 +208,20 @@ delayed_request:
 	/* Send a delayed certificate signing request. */
 	Utility::MkDirP(requestDir, 0700);
 
-	Dictionary::Ptr request = new Dictionary();
-	request->Set("cert_request", CertificateToString(cert));
-	request->Set("ticket", params->Get("ticket"));
+	Dictionary::Ptr request = new Dictionary({
+		{ "cert_request", CertificateToString(cert) },
+		{ "ticket", params->Get("ticket") }
+	});
 
 	Utility::SaveJsonFile(requestPath, 0600, request);
 
-	JsonRpcConnection::SendCertificateRequest(JsonRpcConnection::Ptr(), origin, requestPath);
+	JsonRpcConnection::SendCertificateRequest(nullptr, origin, requestPath);
 
 	result->Set("status_code", 2);
 	result->Set("error", "Certificate request for CN '" + cn + "' is pending. Waiting for approval from the parent Icinga instance.");
 
 	Log(LogInformation, "JsonRpcConnection")
-	    << "Certificate request for CN '" << cn << "' is pending. Waiting for approval.";
+		<< "Certificate request for CN '" << cn << "' is pending. Waiting for approval.";
 
 	return result;
 }
@@ -269,7 +272,7 @@ Value UpdateCertificateHandler(const MessageOrigin::Ptr& origin, const Dictionar
 {
 	if (origin->FromZone && !Zone::GetLocalZone()->IsChildOf(origin->FromZone)) {
 		Log(LogWarning, "ClusterEvents")
-		    << "Discarding 'update certificate' message from '" << origin->FromClient->GetIdentity() << "': Invalid endpoint origin (client not allowed).";
+			<< "Discarding 'update certificate' message from '" << origin->FromClient->GetIdentity() << "': Invalid endpoint origin (client not allowed).";
 
 		return Empty;
 	}
@@ -282,20 +285,20 @@ Value UpdateCertificateHandler(const MessageOrigin::Ptr& origin, const Dictionar
 	if (!listener)
 		return Empty;
 
-	boost::shared_ptr<X509> oldCert = GetX509Certificate(listener->GetDefaultCertPath());
-	boost::shared_ptr<X509> newCert = StringToCertificate(cert);
+	std::shared_ptr<X509> oldCert = GetX509Certificate(listener->GetDefaultCertPath());
+	std::shared_ptr<X509> newCert = StringToCertificate(cert);
 
 	String cn = GetCertificateCN(newCert);
 
 	Log(LogInformation, "JsonRpcConnection")
-	    << "Received certificate update message for CN '" << cn << "'";
+		<< "Received certificate update message for CN '" << cn << "'";
 
 	/* Check if this is a certificate update for a subordinate instance. */
-	boost::shared_ptr<EVP_PKEY> oldKey = boost::shared_ptr<EVP_PKEY>(X509_get_pubkey(oldCert.get()), EVP_PKEY_free);
-	boost::shared_ptr<EVP_PKEY> newKey = boost::shared_ptr<EVP_PKEY>(X509_get_pubkey(newCert.get()), EVP_PKEY_free);
+	std::shared_ptr<EVP_PKEY> oldKey = std::shared_ptr<EVP_PKEY>(X509_get_pubkey(oldCert.get()), EVP_PKEY_free);
+	std::shared_ptr<EVP_PKEY> newKey = std::shared_ptr<EVP_PKEY>(X509_get_pubkey(newCert.get()), EVP_PKEY_free);
 
 	if (X509_NAME_cmp(X509_get_subject_name(oldCert.get()), X509_get_subject_name(newCert.get())) != 0 ||
-	    EVP_PKEY_cmp(oldKey.get(), newKey.get()) != 1) {
+		EVP_PKEY_cmp(oldKey.get(), newKey.get()) != 1) {
 		String certFingerprint = params->Get("fingerprint_request");
 
 		/* Validate the fingerprint format. */
@@ -303,8 +306,8 @@ Value UpdateCertificateHandler(const MessageOrigin::Ptr& origin, const Dictionar
 
 		if (!boost::regex_match(certFingerprint.GetData(), expr)) {
 			Log(LogWarning, "JsonRpcConnection")
-			    << "Endpoint '" << origin->FromClient->GetIdentity() << "' sent an invalid certificate fingerprint: '"
-			    << certFingerprint << "' for CN '" << cn << "'.";
+				<< "Endpoint '" << origin->FromClient->GetIdentity() << "' sent an invalid certificate fingerprint: '"
+				<< certFingerprint << "' for CN '" << cn << "'.";
 			return Empty;
 		}
 
@@ -314,7 +317,7 @@ Value UpdateCertificateHandler(const MessageOrigin::Ptr& origin, const Dictionar
 		/* Save the received signed certificate request to disk. */
 		if (Utility::PathExists(requestPath)) {
 			Log(LogInformation, "JsonRpcConnection")
-			    << "Saved certificate update for CN '" << cn << "'";
+				<< "Saved certificate update for CN '" << cn << "'";
 
 			Dictionary::Ptr request = Utility::LoadJsonFile(requestPath);
 			request->Set("cert_response", cert);
@@ -328,7 +331,7 @@ Value UpdateCertificateHandler(const MessageOrigin::Ptr& origin, const Dictionar
 	String caPath = listener->GetDefaultCaPath();
 
 	Log(LogInformation, "JsonRpcConnection")
-	    << "Updating CA certificate in '" << caPath << "'.";
+		<< "Updating CA certificate in '" << caPath << "'.";
 
 	std::fstream cafp;
 	String tempCaPath = Utility::CreateTempFile(caPath + ".XXXXXX", 0644, cafp);
@@ -341,16 +344,16 @@ Value UpdateCertificateHandler(const MessageOrigin::Ptr& origin, const Dictionar
 
 	if (rename(tempCaPath.CStr(), caPath.CStr()) < 0) {
 		BOOST_THROW_EXCEPTION(posix_error()
-		    << boost::errinfo_api_function("rename")
-		    << boost::errinfo_errno(errno)
-		    << boost::errinfo_file_name(tempCaPath));
+			<< boost::errinfo_api_function("rename")
+			<< boost::errinfo_errno(errno)
+			<< boost::errinfo_file_name(tempCaPath));
 	}
 
 	/* Update signed certificate. */
 	String certPath = listener->GetDefaultCertPath();
 
 	Log(LogInformation, "JsonRpcConnection")
-	    << "Updating client certificate for CN '" << cn << "' in '" << certPath << "'.";
+		<< "Updating client certificate for CN '" << cn << "' in '" << certPath << "'.";
 
 	std::fstream certfp;
 	String tempCertPath = Utility::CreateTempFile(certPath + ".XXXXXX", 0644, certfp);
@@ -363,9 +366,9 @@ Value UpdateCertificateHandler(const MessageOrigin::Ptr& origin, const Dictionar
 
 	if (rename(tempCertPath.CStr(), certPath.CStr()) < 0) {
 		BOOST_THROW_EXCEPTION(posix_error()
-		    << boost::errinfo_api_function("rename")
-		    << boost::errinfo_errno(errno)
-		    << boost::errinfo_file_name(tempCertPath));
+			<< boost::errinfo_api_function("rename")
+			<< boost::errinfo_errno(errno)
+			<< boost::errinfo_file_name(tempCertPath));
 	}
 
 	/* Remove ticket for successful signing request. */
@@ -373,14 +376,14 @@ Value UpdateCertificateHandler(const MessageOrigin::Ptr& origin, const Dictionar
 
 	if (unlink(ticketPath.CStr()) < 0 && errno != ENOENT) {
 		BOOST_THROW_EXCEPTION(posix_error()
-		    << boost::errinfo_api_function("unlink")
-		    << boost::errinfo_errno(errno)
-		    << boost::errinfo_file_name(ticketPath));
+			<< boost::errinfo_api_function("unlink")
+			<< boost::errinfo_errno(errno)
+			<< boost::errinfo_file_name(ticketPath));
 	}
 
 	/* Update the certificates at runtime and reconnect all endpoints. */
 	Log(LogInformation, "JsonRpcConnection")
-	    << "Updating the client certificate for CN '" << cn << "' at runtime and reconnecting the endpoints.";
+		<< "Updating the client certificate for CN '" << cn << "' at runtime and reconnecting the endpoints.";
 
 	listener->UpdateSSLContext();
 
