@@ -59,7 +59,7 @@ void JsonRpcConnection::StaticInitialize()
 	l_JsonRpcConnectionTimeoutTimer->SetInterval(15);
 	l_JsonRpcConnectionTimeoutTimer->Start();
 
-	l_JsonRpcConnectionWorkQueueCount = Application::GetConcurrency();
+	l_JsonRpcConnectionWorkQueueCount = Configuration::Concurrency;
 	l_JsonRpcConnectionWorkQueues = new WorkQueue[l_JsonRpcConnectionWorkQueueCount];
 
 	for (size_t i = 0; i < l_JsonRpcConnectionWorkQueueCount; i++) {
@@ -248,7 +248,8 @@ void JsonRpcConnection::MessageHandler(const String& jsonString)
 
 bool JsonRpcConnection::ProcessMessage()
 {
-	ssize_t maxMessageLength = 64 * 1024;
+	/* Limit for anonymous clients (signing requests and not configured endpoints. */
+	ssize_t maxMessageLength = 1024 * 1024;
 
 	if (m_Endpoint)
 		maxMessageLength = -1; /* no limit */
