@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -25,13 +25,13 @@
 namespace icinga
 {
 
-class I2_REMOTE_API VariableQueryHandler : public HttpHandler
+class VariableQueryHandler final : public HttpHandler
 {
 public:
 	DECLARE_PTR_TYPEDEFS(VariableQueryHandler);
 
-	virtual bool HandleRequest(const ApiUser::Ptr& user, HttpRequest& request,
-	    HttpResponse& response, const Dictionary::Ptr& params) override;
+	bool HandleRequest(const ApiUser::Ptr& user, HttpRequest& request,
+		HttpResponse& response, const Dictionary::Ptr& params) override;
 };
 
 }
