@@ -20,6 +20,7 @@
 #include "remote/zone.hpp"
 #include "remote/zone-ti.cpp"
 #include "remote/jsonrpcconnection.hpp"
+#include "base/array.hpp"
 #include "base/objectlock.hpp"
 #include "base/logger.hpp"
 
@@ -33,6 +34,9 @@ void Zone::OnAllConfigLoaded()
 
 	m_Parent = Zone::GetByName(GetParentRaw());
 
+	if (m_Parent && m_Parent->IsGlobal())
+		BOOST_THROW_EXCEPTION(ScriptError("Zone '" + GetName() + "' can not have a global zone as parent.", GetDebugInfo()));
+
 	Zone::Ptr zone = m_Parent;
 	int levels = 0;
 
@@ -86,11 +90,21 @@ std::set<Endpoint::Ptr> Zone::GetEndpoints() const
 	return result;
 }
 
-std::vector<Zone::Ptr> Zone::GetAllParents() const
+std::vector<Zone::Ptr> Zone::GetAllParentsRaw() const
 {
 	return m_AllParents;
 }
 
+Array::Ptr Zone::GetAllParents() const
+{
+	auto result (new Array);
+
+	for (auto& parent : m_AllParents)
+		result->Add(parent->GetName());
+
+	return result;
+}
+
 bool Zone::CanAccessObject(const ConfigObject::Ptr& object)
 {
 	Zone::Ptr object_zone;
