@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -16,39 +16,34 @@
  * along with this program; if not, write to the Free Software Foundation     *
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ******************************************************************************/
-#include <windows.h>
-#include <Shlwapi.h>
+
+#include "plugins/thresholds.hpp"
+#include <boost/program_options.hpp>
 #include <iostream>
+#include <windows.h>
+#include <shlwapi.h>
 #include <wuapi.h>
 #include <wuerror.h>
 
-#include "check_update.h"
-
 #define VERSION 1.0
 
 #define CRITERIA L"(IsInstalled = 0 and CategoryIDs contains '0fa1201d-4330-4fa8-8ae9-b877473b6441') or (IsInstalled = 0 and CategoryIDs contains 'E6CF1350-C01B-414D-A61F-263D14D133B4')"
 
 namespace po = boost::program_options;
 
-static BOOL debug = FALSE;
-
-INT wmain(INT argc, WCHAR **argv) 
+struct printInfoStruct
 {
-	printInfoStruct printInfo = { FALSE, FALSE, 0, FALSE, FALSE, FALSE };
-	po::variables_map vm;
+	bool warn{false};
+	bool crit{false};
+	LONG numUpdates{0};
+	bool important{false};
+	bool reboot{false};
+	bool careForCanRequest{false};
+};
 
-	INT ret = parseArguments(argc, argv, vm, printInfo);
-	if (ret != -1)
-		return ret;
-	
-	ret = check_update(printInfo);
-	if (ret != -1)
-		return ret;
+static bool l_Debug;
 
-	return printOutput(printInfo);
-}
-
-INT parseArguments(INT ac, WCHAR **av, po::variables_map& vm, printInfoStruct& printInfo) 
+static int parseArguments(int ac, WCHAR **av, po::variables_map& vm, printInfoStruct& printInfo)
 {
 	WCHAR namePath[MAX_PATH];
 	GetModuleFileName(NULL, namePath, MAX_PATH);
@@ -65,19 +60,19 @@ INT parseArguments(INT ac, WCHAR **av, po::variables_map& vm, printInfoStruct& p
 		("possible-reboot", "Treat \"update may need reboot\" as \"update needs reboot\"")
 		;
 
-	po::basic_command_line_parser<WCHAR> parser(ac, av);
+	po::wcommand_line_parser parser(ac, av);
 
 	try {
 		po::store(
 			parser
 			.options(desc)
 			.style(
-			po::command_line_style::unix_style |
-			po::command_line_style::allow_long_disguise)
+				po::command_line_style::unix_style |
+				po::command_line_style::allow_long_disguise)
 			.run(),
 			vm);
 		vm.notify();
-	} catch (std::exception& e) {
+	} catch (const std::exception& e) {
 		std::cout << e.what() << '\n' << desc << '\n';
 		return 3;
 	}
@@ -119,24 +114,18 @@ INT parseArguments(INT ac, WCHAR **av, po::variables_map& vm, printInfoStruct& p
 		return 0;
 	}
 
-	if (vm.count("warning"))
-		printInfo.warn = TRUE;
+	printInfo.warn = vm.count("warning") > 0;
+	printInfo.crit = vm.count("critical") > 0;
+	printInfo.careForCanRequest = vm.count("possible-reboot") > 0;
 
-	if (vm.count("critical"))
-		printInfo.crit = TRUE;
-
-	if (vm.count("possible-reboot"))
-		printInfo.careForCanRequest = TRUE;
-
-	if (vm.count("debug"))
-		debug = TRUE;
+	l_Debug = vm.count("debug") > 0;
 
 	return -1;
 }
 
-INT printOutput(const printInfoStruct& printInfo)
+static int printOutput(const printInfoStruct& printInfo)
 {
-	if (debug)
+	if (l_Debug)
 		std::wcout << L"Constructing output string" << '\n';
 
 	state state = OK;
@@ -160,15 +149,15 @@ INT printOutput(const printInfoStruct& printInfo)
 		break;
 	}
 
-	std::wcout << output << printInfo.numUpdates << L" | update=" << printInfo.numUpdates << L";"
+	std::wcout << output << printInfo.numUpdates << L" | 'update'=" << printInfo.numUpdates << L";"
 		<< printInfo.warn << L";" << printInfo.crit << L";0;" << '\n';
 
 	return state;
 }
 
-INT check_update(printInfoStruct& printInfo) 
+static int check_update(printInfoStruct& printInfo)
 {
-	if (debug)
+	if (l_Debug)
 		std::wcout << "Initializing COM library" << '\n';
 	CoInitializeEx(NULL, COINIT_APARTMENTTHREADED);
 	ISearchResult *pResult;
@@ -177,24 +166,24 @@ INT check_update(printInfoStruct& printInfo)
 	BSTR criteria = NULL;
 
 	HRESULT err;
-	if (debug)
+	if (l_Debug)
 		std::wcout << "Creating UpdateSession and UpdateSearcher" << '\n';
-	CoCreateInstance(CLSID_UpdateSession, NULL, CLSCTX_INPROC_SERVER, IID_IUpdateSession, (LPVOID*)&pSession);
+	CoCreateInstance(CLSID_UpdateSession, NULL, CLSCTX_INPROC_SERVER, IID_IUpdateSession, (void **)&pSession);
 	pSession->CreateUpdateSearcher(&pSearcher);
 
 	/*
-	 IsInstalled = 0: All updates, including languagepacks and features
-	 BrowseOnly = 0: No features or languagepacks, security and unnamed
-	 BrowseOnly = 1: Nothing, broken
-	 RebootRequired = 1: Reboot required
+	* IsInstalled = 0: All updates, including languagepacks and features
+	* BrowseOnly = 0: No features or languagepacks, security and unnamed
+	* BrowseOnly = 1: Nothing, broken
+	* RebootRequired = 1: Reboot required
 	*/
 
 	criteria = SysAllocString(CRITERIA);
 	// https://msdn.microsoft.com/en-us/library/windows/desktop/aa386526%28v=vs.85%29.aspx
 	// https://msdn.microsoft.com/en-us/library/ff357803%28v=vs.85%29.aspx
 
-	if (debug)
-		std::wcout << L"Querrying updates from server" << '\n';
+	if (l_Debug)
+		std::wcout << L"Querying updates from server" << '\n';
 
 	err = pSearcher->Search(criteria, &pResult);
 	if (!SUCCEEDED(err))
@@ -212,31 +201,31 @@ INT check_update(printInfoStruct& printInfo)
 		return -1;
 
 	printInfo.numUpdates = updateSize;
-//	printInfo.important = printInfo.warn;
+	//	printInfo.important = printInfo.warn;
 
 	IInstallationBehavior *pIbehav;
 	InstallationRebootBehavior updateReboot;
 
 	for (LONG i = 0; i < updateSize; i++) {
 		pCollection->get_Item(i, &pUpdate);
-		if (debug) {
+		if (l_Debug) {
 			std::wcout << L"Checking reboot behaviour of update number " << i << '\n';
 		}
 		pUpdate->get_InstallationBehavior(&pIbehav);
 		pIbehav->get_RebootBehavior(&updateReboot);
 		if (updateReboot == irbAlwaysRequiresReboot) {
-			printInfo.reboot = TRUE;
-			if (debug)
+			printInfo.reboot = true;
+			if (l_Debug)
 				std::wcout << L"It requires reboot" << '\n';
 			continue;
 		}
 		if (printInfo.careForCanRequest && updateReboot == irbCanRequestReboot)
-			if (debug)
+			if (l_Debug)
 				std::wcout << L"It requires reboot" << '\n';
-			printInfo.reboot = TRUE;
+		printInfo.reboot = true;
 	}
 
-	if (debug)
+	if (l_Debug)
 		std::wcout << L"Cleaning up and returning" << '\n';
 
 	SysFreeString(criteria);
@@ -244,9 +233,25 @@ INT check_update(printInfoStruct& printInfo)
 	return -1;
 
 die:
-	die(err);
+	printErrorInfo(err);
 	CoUninitialize();
 	if (criteria)
 		SysFreeString(criteria);
 	return 3;
 }
+
+int wmain(int argc, WCHAR **argv)
+{
+	printInfoStruct printInfo;
+	po::variables_map vm;
+
+	int ret = parseArguments(argc, argv, vm, printInfo);
+	if (ret != -1)
+		return ret;
+
+	ret = check_update(printInfo);
+	if (ret != -1)
+		return ret;
+
+	return printOutput(printInfo);
+}
