@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -60,9 +60,10 @@ static void CheckNotification(const Checkable::Ptr& checkable, bool expected, No
 
 BOOST_AUTO_TEST_CASE(host_1attempt)
 {
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	Host::Ptr host = new Host();
+	host->SetActive(true);
 	host->SetMaxCheckAttempts(1);
 	host->Activate();
 	host->SetAuthority(true);
@@ -108,9 +109,10 @@ BOOST_AUTO_TEST_CASE(host_1attempt)
 
 BOOST_AUTO_TEST_CASE(host_2attempts)
 {
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	Host::Ptr host = new Host();
+	host->SetActive(true);
 	host->SetMaxCheckAttempts(2);
 	host->Activate();
 	host->SetAuthority(true);
@@ -163,9 +165,10 @@ BOOST_AUTO_TEST_CASE(host_2attempts)
 
 BOOST_AUTO_TEST_CASE(host_3attempts)
 {
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	Host::Ptr host = new Host();
+	host->SetActive(true);
 	host->SetMaxCheckAttempts(3);
 	host->Activate();
 	host->SetAuthority(true);
@@ -225,9 +228,10 @@ BOOST_AUTO_TEST_CASE(host_3attempts)
 
 BOOST_AUTO_TEST_CASE(service_1attempt)
 {
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	Service::Ptr service = new Service();
+	service->SetActive(true);
 	service->SetMaxCheckAttempts(1);
 	service->Activate();
 	service->SetAuthority(true);
@@ -273,9 +277,10 @@ BOOST_AUTO_TEST_CASE(service_1attempt)
 
 BOOST_AUTO_TEST_CASE(service_2attempts)
 {
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	Service::Ptr service = new Service();
+	service->SetActive(true);
 	service->SetMaxCheckAttempts(2);
 	service->Activate();
 	service->SetAuthority(true);
@@ -328,9 +333,10 @@ BOOST_AUTO_TEST_CASE(service_2attempts)
 
 BOOST_AUTO_TEST_CASE(service_3attempts)
 {
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	Service::Ptr service = new Service();
+	service->SetActive(true);
 	service->SetMaxCheckAttempts(3);
 	service->Activate();
 	service->SetAuthority(true);
@@ -393,11 +399,12 @@ BOOST_AUTO_TEST_CASE(host_flapping_notification)
 #ifndef I2_DEBUG
 	BOOST_WARN_MESSAGE(false, "This test can only be run in a debug build!");
 #else /* I2_DEBUG */
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	int timeStepInterval = 60;
 
 	Host::Ptr host = new Host();
+	host->SetActive(true);
 	host->Activate();
 	host->SetAuthority(true);
 	host->SetStateRaw(ServiceOK);
@@ -446,11 +453,12 @@ BOOST_AUTO_TEST_CASE(service_flapping_notification)
 #ifndef I2_DEBUG
 	BOOST_WARN_MESSAGE(false, "This test can only be run in a debug build!");
 #else /* I2_DEBUG */
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	int timeStepInterval = 60;
 
 	Service::Ptr service = new Service();
+	service->SetActive(true);
 	service->Activate();
 	service->SetAuthority(true);
 	service->SetStateRaw(ServiceOK);
@@ -500,7 +508,7 @@ BOOST_AUTO_TEST_CASE(service_flapping_problem_notifications)
 #ifndef I2_DEBUG
 	BOOST_WARN_MESSAGE(false, "This test can only be run in a debug build!");
 #else /* I2_DEBUG */
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	int timeStepInterval = 60;
 
@@ -598,7 +606,7 @@ BOOST_AUTO_TEST_CASE(service_flapping_ok_into_bad)
 #ifndef I2_DEBUG
 	BOOST_WARN_MESSAGE(false, "This test can only be run in a debug build!");
 #else /* I2_DEBUG */
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	int timeStepInterval = 60;
 
@@ -676,7 +684,7 @@ BOOST_AUTO_TEST_CASE(service_flapping_ok_over_bad_into_ok)
 #ifndef I2_DEBUG
 	BOOST_WARN_MESSAGE(false, "This test can only be run in a debug build!");
 #else /* I2_DEBUG */
-	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(boost::bind(&NotificationHandler, _1, _2));
+	boost::signals2::connection c = Checkable::OnNotificationsRequested.connect(std::bind(&NotificationHandler, _1, _2));
 
 	int timeStepInterval = 60;
 
