@@ -1,6 +1,6 @@
 /******************************************************************************
  * Icinga 2                                                                   *
- * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
+ * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
  *                                                                            *
  * This program is free software; you can redistribute it and/or              *
  * modify it under the terms of the GNU General Public License                *
@@ -21,20 +21,24 @@
 #include "config/configitem.hpp"
 #include "base/application.hpp"
 #include "base/loader.hpp"
+#include "icingaapplication-fixture.hpp"
 #include <BoostTestTargetConfig.h>
 
 using namespace icinga;
 
 struct LivestatusFixture
 {
-	LivestatusFixture(void)
+	LivestatusFixture()
 	{
+		// ensure IcingaApplication is initialized before we try to add config
+		IcingaApplicationFixture icinga;
+
 		BOOST_TEST_MESSAGE("Preparing config objects...");
 
-		ConfigItem::RunWithActivationContext(new Function("CreateTestObjects", WrapFunction(CreateTestObjects)));
+		ConfigItem::RunWithActivationContext(new Function("CreateTestObjects", CreateTestObjects));
 	}
 
-	static void CreateTestObjects(void)
+	static void CreateTestObjects()
 	{
 		String config = R"CONFIG(
 object CheckCommand "dummy" {
@@ -58,7 +62,7 @@ apply Service "livestatus" {
 }
 )CONFIG";
 
-		Expression *expr = ConfigCompiler::CompileText("<livestatus>", config);
+		std::unique_ptr<Expression> expr = ConfigCompiler::CompileText("<livestatus>", config);
 		expr->Evaluate(*ScriptFrame::GetCurrentFrame());
 	}
 };
